@@ -182,6 +182,7 @@ Dtime::Dtime(QWidget * parent)
   v3->addItem(spacer3, 0, 9, 2, 1);
 
   QGridLayout *top = new QGridLayout( this );
+  top->setMargin( 0 );
   top->setSpacing( KDialog::spacingHint() );
 
   top->addWidget(dateBox, 1,0);
@@ -262,7 +263,7 @@ void Dtime::configChanged(){
 
 void Dtime::load()
 {
-  KConfig _config( "kcmclockrc", KConfig::CascadeConfig  );
+  KConfig _config( "kcmclockrc", KConfig::NoGlobals  );
   KConfigGroup config(&_config, "NTP");
   timeServerList->addItems(config.readEntry("servers",
     i18n("Public Time Server (pool.ntp.org),\
@@ -285,7 +286,7 @@ oceania.pool.ntp.org")).split(',', QString::SkipEmptyParts));
 
 void Dtime::save()
 {
-  KConfig _config("kcmclockrc", KConfig::CascadeConfig);
+  KConfig _config("kcmclockrc", KConfig::NoGlobals);
   KConfigGroup config(&_config, "NTP");
 
   // Save the order, but don't duplicate!
