@@ -31,8 +31,6 @@
 #ifndef __MOUSECONFIG_H__
 #define __MOUSECONFIG_H__
 
-#include <QButtonGroup>
-#include <QDialog>
 #include <QLabel>
 #include <QtGui/QLCDNumber>
 #include <QPushButton>
@@ -138,7 +136,6 @@ private:
   KIntNumInput *dragStartDist;
   KIntNumInput *wheelScrollLines;
 
-  Q3ButtonGroup *handedBox;
 //  QRadioButton *leftHanded, *rightHanded;
 //  QCheckBox *doubleClick;
 //  QCheckBox *cbAutoSelect;
