@@ -120,10 +120,6 @@ void ShortcutsModule::initGUI()
 #define NOSLOTS
 //#define KICKER_ALL_BINDINGS
 #include "../../kwin/kwinbindings.cpp"
-//#include "../../kicker/kicker/core/kickerbindings.cpp"
-//#include "../../kicker/taskbar/taskbarbindings.cpp"
-//#include "../../kdesktop/kdesktopbindings.cpp"
-#include "../../klipper/klipperbindings.cpp"
 #include "../kxkb/kxkbbindings.cpp"
 
 	kDebug(125) << "B-----------";
