@@ -8,9 +8,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,8 +26,7 @@
 
 #include <config-workspace.h>
 
-#include <klocale.h>
-#include <kio/global.h>
+#include <KDE/KLocale>
 #include <kio/udsentry.h>
 
 #define KFI_NAME                     "kfontinst"
@@ -35,13 +35,13 @@
 #ifdef KDE_BINDIR
 #define KFI_INSTALLER KDE_BINDIR"/kfontinst"
 #define KFI_VIEWER    KDE_BINDIR"/kfontview"
-#define KFI_PRINTER   KDE_BINDIR"/kfontprint"
 #else
 #define KFI_INSTALLER "kfontinst"
 #define KFI_VIEWER    "kfontview"
-#define KFI_PRINTER   "kfontprint"
 #endif
 
+#define KFI_PRINTER   "kfontprint"
+
 #define KFI_PRINT_GROUP              "Print"
 #define KFI_KIO_FONTS_PROTOCOL       "fonts"
 #define KFI_KIO_FONTS_USER           I18N_NOOP("Personal")
