@@ -23,8 +23,9 @@
 #include <QQueue>
 #include <QMap>
 
-const int GROUP_LIMIT = 4;
 
+const int GROUP_LIMIT = 4;
+const int MAX_LABEL_LEN = 3;
 
 /* Utility classes for per-window/per-application layout implementation
 */
@@ -37,7 +38,6 @@ enum SwitchingPolicy {
 };
 
 
-
 inline QString createPair(QString key, QString value) 
 {
 	if( value.isEmpty() )
@@ -46,9 +46,11 @@ inline QString createPair(QString key, QString value)
 } 
 
 struct LayoutUnit {
+private:
+	QString displayName;
+public:
 	QString layout;
 	QString variant;
-	QString displayName;
 	
 	LayoutUnit() {}
 	
@@ -60,6 +62,12 @@ struct LayoutUnit {
 	LayoutUnit(QString pair) {
 		setFromPair( pair );
 	}
+
+        void setDisplayName(const QString& name) { displayName = name; }
+
+        QString getDisplayName() const {
+            return !displayName.isEmpty() ? displayName : getDefaultDisplayName(layout, variant);
+        }
 	
 	void setFromPair(const QString& pair) {
 		layout = parseLayout(pair);
@@ -69,20 +77,22 @@ struct LayoutUnit {
 	QString toPair() const {
 		return createPair(layout, variant);
 	}
-	
+/*	
 	bool operator<(const LayoutUnit& lu) const {
 		return layout<lu.layout ||
 				(layout==lu.layout && variant<lu.variant);
 	}
-	
+*/		
 	bool operator!=(const LayoutUnit& lu) const {
 		return layout!=lu.layout || variant!=lu.variant;
 	}
-	
 	bool operator==(const LayoutUnit& lu) const {
 // 		kDebug() << layout << "==" << lu.layout << "&&" << variant << "==" << lu.variant;
 		return layout==lu.layout && variant==lu.variant;
 	}
+
+
+        static QString getDefaultDisplayName(const QString& layout, const QString& variant="");
 	
 //private:
 	static const QString parseLayout(const QString &layvar);
@@ -92,40 +102,45 @@ struct LayoutUnit {
 extern const LayoutUnit DEFAULT_LAYOUT_UNIT;
 extern const char* DEFAULT_MODEL;
 
+struct XkbConfig {
+    QString model;
+    QStringList options;
+    QList<LayoutUnit> layouts;
+};
 
 class KxkbConfig
 {
 public:
-	enum { LOAD_INIT_OPTIONS, LOAD_ACTIVE_OPTIONS, LOAD_ALL };
+	enum { LOAD_ACTIVE_OPTIONS, LOAD_ALL };
+        static const char* OPTIONS_SEPARATOR;
 	
 	bool m_useKxkb;
 	bool m_indicatorOnly;
 	bool m_showSingle;
 	bool m_showFlag;
-	bool m_enableXkbOptions;
+//	bool m_enableXkbOptions;
 	bool m_resetOldOptions;
 	bool m_stickySwitching;
 	int m_stickySwitchingDepth;
 	SwitchingPolicy m_switchingPolicy;
 	
 	QString m_model;
-	QString m_options;
+	QStringList m_options;
 	QList<LayoutUnit> m_layouts;
 
 	KxkbConfig();
 	int getDefaultLayout();
 	
 	bool load(int loadMode);
-	bool setConfiguredLayouts(QList<LayoutUnit> layoutUnits);
+	void setConfiguredLayouts(XkbConfig xkbConfig);
 	void save();
 	void setDefaults();
 	
 	QStringList getLayoutStringList(/*bool compact*/);
-	static QString getDefaultDisplayName(const QString& code_);
-	static QString getDefaultDisplayName(const LayoutUnit& layoutUnit, bool single=false);
 
-private:	
 	void updateDisplayNames();
+
+private:
 	static const QMap<QString, QString> parseIncludesMap(const QStringList& pairList);
 };
 
