@@ -22,8 +22,6 @@
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <QtGui/QWidget>
-
 #include <libxklavier/xklavier.h>
 
 #include "rules.h"
@@ -31,13 +29,14 @@
 #include "xklavier_adaptor.h"
 
 
+#define KDE_TRANSLATE 1
 #define VERBOSE 0
 
 class XKlavierAdaptorPriv {
 public:
 	QHash<QString, QString> m_models;
 	QHash<QString, QString> m_layouts;
-	QHash<QString, QStringList*> m_variants;
+	QHash<QString, QList<XkbVariant>*> m_variants;
 	QHash<QString, XkbOption> m_options;
 	QHash<QString, XkbOptionGroup> m_optionGroups;
 
@@ -54,40 +53,35 @@ XklConfigRegistry *XKlavierAdaptorPriv::config;
 
 XKlavierAdaptor::XKlavierAdaptor(Display* dpy)
 {
-  priv = new XKlavierAdaptorPriv();
-  
-  g_type_init();
+    priv = new XKlavierAdaptorPriv();
 
-	QString locale = KGlobal::locale()->language();
-	if( ! KGlobal::locale()->country().isEmpty() ) {
-//		locale += KGlobal::_locale->country();
-//		locale += "UTF-8";
-	}
-	kDebug() << "Setting LC_MESSAGES for libxklavier: " << locale;
-//	setlocale(LC_ALL, locale.toLatin1());
-	setlocale(LC_MESSAGES, locale.toLatin1());
+    g_type_init();
 
+    priv->engine = xkl_engine_get_instance(dpy);
+    if (priv->engine == NULL) {
+        kError() << "XKlavier engine cannot be initialized!" << endl;
+        return; // throw
+    }
 
-	priv->engine = xkl_engine_get_instance(dpy);
-	if (priv->engine == NULL) {
-		kError() << "XKlavier engine cannot be initialized!" << endl;
-		return; // throw
-	}
-	
+#if KDE_TRANSLATE == 1
+    // try to translate layout names by countries in desktop_kdebase if translations are missing from x.org
+    // this is poor man's translation as it's good only for layout names and only those which match country names
+    KGlobal::locale()->insertCatalog("desktop_kdebase");
+#endif
 }
 
 QHash<QString, QString> XKlavierAdaptor::getModels() { return priv->m_models; }
 QHash<QString, QString> XKlavierAdaptor::getLayouts() { return priv->m_layouts; }
 QHash<QString, XkbOption> XKlavierAdaptor::getOptions() { return priv->m_options; }
 QHash<QString, XkbOptionGroup> XKlavierAdaptor::getOptionGroups() { return priv->m_optionGroups; }
-QHash<QString, QStringList*> XKlavierAdaptor::getVariants() { return priv->m_variants; }
+QHash<QString, QList<XkbVariant>*> XKlavierAdaptor::getVariants() { return priv->m_variants; }
 
 
 
 static void processModel(XklConfigRegistry*, const XklConfigItem* configItem, gpointer userData)
 {
-	QString model = configItem->name;
-	QString desc = configItem->description;
+	QString model = QString::fromUtf8(configItem->name);
+	QString desc = QString::fromUtf8(configItem->description);
 
 #if VERBOSE == 1
 	  kDebug() << "model: " << model << " - " << desc;
@@ -99,28 +93,33 @@ static void processModel(XklConfigRegistry*, const XklConfigItem* configItem, gp
 
 static void processVariants(XklConfigRegistry*, const XklConfigItem* configItem, gpointer userData)
 {
-	QString variant = configItem->name;
+        XkbVariant variant;
+	variant.name = QString::fromUtf8(configItem->name);
+        variant.description = QString::fromUtf8(configItem->description);
 	QString layout = ((XKlavierAdaptorPriv*)userData)->currLayout;
 
 #if VERBOSE == 1
-	  kDebug() << "\tvariant: " << variant << " (parent: " << layout << ")";
+	kDebug() << "\tvariant: " << variant.name << "-" << variant.description << " (parent: " << layout << ")";
 #endif
 
-	QStringList* vars = ((XKlavierAdaptorPriv*)userData)->m_variants[layout];
-	vars->append(variant);	//TODO: //QString(configItem->description));
+	QList<XkbVariant>* vars = ((XKlavierAdaptorPriv*)userData)->m_variants[layout];
+	vars->append(variant);
 }
 
 
 static void processLayout(XklConfigRegistry*, const XklConfigItem* configItem, gpointer userData)
 {
-	QString layout = configItem->name;
-	QString desc = configItem->description;
+	QString layout = QString::fromUtf8(configItem->name);
+	QString desc = QString::fromUtf8(configItem->description);
+#if KDE_TRANSLATE == 1
+        desc = i18nc("Name", desc.toUtf8().constData());
+#endif
 
 #if VERBOSE == 1
 	kDebug() << "layout: " << layout << " - " << desc;
 #endif
 	((XKlavierAdaptorPriv*)userData)->m_layouts.insert(layout, desc);
-	((XKlavierAdaptorPriv*)userData)->m_variants.insert(layout, new QStringList());
+	((XKlavierAdaptorPriv*)userData)->m_variants.insert(layout, new QList<XkbVariant>());
 	
 	((XKlavierAdaptorPriv*)userData)->currLayout = layout;
 	xkl_config_registry_foreach_layout_variant(XKlavierAdaptorPriv::config, 
@@ -132,8 +131,8 @@ static void processOptions(XklConfigRegistry*, const XklConfigItem* configItem,
 {
 	XkbOption option;
 	
-	option.name = configItem->name;
-	option.description = configItem->description;
+	option.name = QString::fromUtf8(configItem->name);
+	option.description = QString::fromUtf8(configItem->description);
 	option.group = ((XKlavierAdaptorPriv*)userData)->currGroup;
 
 #if VERBOSE == 1
@@ -147,8 +146,8 @@ static void processOptions(XklConfigRegistry*, const XklConfigItem* configItem,
 static void processOptionGroup(XklConfigRegistry*, const XklConfigItem* configItem, void *userData)
 {
 	XkbOptionGroup group;
-	group.name = configItem->name;
-	group.description = configItem->description;
+	group.name = QString::fromUtf8(configItem->name);
+	group.description = QString::fromUtf8(configItem->description);
 	group.exclusive = ! GPOINTER_TO_INT (g_object_get_data (G_OBJECT (configItem),
 	                                                          XCI_PROP_ALLOW_MULTIPLE_SELECTION));
 	
@@ -165,52 +164,84 @@ static void processOptionGroup(XklConfigRegistry*, const XklConfigItem* configIt
 }
 
 
+static const int LOCALE_CATEGORY = LC_ALL;
+
 void XKlavierAdaptor::loadXkbConfig(bool layoutsOnly)
 {
-	if( priv->engine == NULL )
-	    return;
+    if( priv->engine == NULL )
+        return;
+    
+    const char* currLocale = setlocale(LOCALE_CATEGORY, NULL);
 
-	kDebug() << "Xklavier initialized";
-	priv->config = xkl_config_registry_get_instance(priv->engine);
+    QString locale = KGlobal::locale()->language();
+    if( locale.indexOf('_') == -1 ) {   // TODO: do we have to do this?
+        QString country = KGlobal::locale()->country();
+        if( ! country.isEmpty() ) {
+            locale += "_";
+	    locale += country.toUpper();
+        }
+    }
+//  locale = "uk_UA";   // testing
+//  locale = "en_US";
+    locale += ".UTF-8";
+    kDebug() << "Setting LC_ALL for libxklavier: " << locale;
 
-	xkl_config_registry_load(priv->config);
+    const char* newLocale = setlocale(LOCALE_CATEGORY, locale.toLatin1());
+    if( newLocale == NULL ) {
+        kDebug() << "Setting locale " << locale << " failed - will use 'C' locale";
+        setlocale(LC_ALL, "C");
+    }
+
+    kDebug() << "Xklavier initialized";
+    priv->config = xkl_config_registry_get_instance(priv->engine);
+
+    xkl_config_registry_load(priv->config);
 	
-	void *userData = priv;
+    void *userData = priv;
 
-	xkl_config_registry_set_custom_charset(priv->config, "UTF-8");
+//	xkl_config_registry_set_custom_charset(priv->config, "UTF-8");
 	
-	xkl_config_registry_foreach_layout(priv->config, processLayout, userData);
+    xkl_config_registry_foreach_layout(priv->config, processLayout, userData);
 
-	if( ! layoutsOnly ) {
-	  xkl_config_registry_foreach_model(priv->config, processModel, userData);
+    if( ! layoutsOnly ) {
+	xkl_config_registry_foreach_model(priv->config, processModel, userData);
+	xkl_config_registry_foreach_option_group(priv->config, processOptionGroup, userData);
+    }
 
-	  xkl_config_registry_foreach_option_group(priv->config, processOptionGroup, userData);
-	}
+    kDebug() << priv->m_layouts.count() << "total layouts" << priv->m_models.count() << "models";
 
-	g_object_unref(priv->config);
+    setlocale(LOCALE_CATEGORY, currLocale);
+
+    g_object_unref(priv->config);
 }
 
 XKlavierAdaptor::~XKlavierAdaptor()
 {
-	g_object_unref(priv->engine);
+    g_object_unref(priv->engine);
 //	delete priv;
 //	kDebug() << "Finalizer";
 }
 
-QList<LayoutUnit> 
+XkbConfig 
 XKlavierAdaptor::getGroupNames()
 {
-    QList<LayoutUnit> list;
+    XkbConfig xkbConfig;
 
+//    kDebug() << "retrieving active layout from server...";
     XklConfigRec configRec;
     xkl_config_rec_get_from_server(&configRec, priv->engine);
 
-    for(int ii=0; configRec.layouts[ii] != NULL; ii++) {
+    for(int ii=0; configRec.layouts[ii] != NULL && ii < GROUP_LIMIT; ii++) {
 	LayoutUnit lu;
 	lu.layout = configRec.layouts[ii];
 	lu.variant = configRec.variants[ii];
-	list << lu;
-	kDebug() << "layout nm:" << lu.layout << "variant:" << lu.variant;
+	xkbConfig.layouts << lu;
+	kDebug() << " layout nm:" << lu.layout << "variant:" << lu.variant;
+    }
+
+    for(int ii=0; configRec.options[ii] != NULL && ii < 15; ii++) {
+	xkbConfig.options << configRec.options[ii];
+	kDebug() << " option:" << configRec.options[ii];
     }
 
 //        const char **gn = xkl_engine_get_groups_names(priv->engine);
@@ -219,7 +250,7 @@ XKlavierAdaptor::getGroupNames()
 //	for (i = 0; i < gt; i++)
 //	    kDebug() << "group:" << gn[i];
 
-    return list;
+    return xkbConfig;
 }
 
 static XKlavierAdaptor* instance = NULL;
@@ -239,6 +270,12 @@ XKlavierAdaptor::startListening()
     return xkl_engine_start_listen(priv->engine, XKLL_TRACK_KEYBOARD_STATE);
 }
 
+int
+XKlavierAdaptor::stopListening()
+{
+    return xkl_engine_start_listen(priv->engine, XKLL_TRACK_KEYBOARD_STATE);
+}
+
 int 
 XKlavierAdaptor::filterEvents(XEvent* ev)
 {
