@@ -31,11 +31,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/kdmitem.h"
 #include "themer/kdmlabel.h"
 
+#include <KColorScheme>
+#include <KConfigGroup>
 #include <klocale.h>
 #include <kseparator.h>
 #include <kstandarddirs.h>
 #include <kstringhandler.h>
-#include <KConfigGroup>
 
 #include <QAction>
 #include <QBuffer>
@@ -145,7 +146,6 @@ KGreeter::KGreeter( bool framed )
   , nNormals( 0 )
   , nSpecials( 0 )
   , curPrev( 0 )
-  , curSel( 0 )
   , prevValid( true )
   , needLoad( false )
 {
@@ -166,7 +166,9 @@ KGreeter::KGreeter( bool framed )
 
 	sessMenu = new QMenu( this );
 	connect( sessMenu, SIGNAL(triggered( QAction * )),
-	         SLOT(slotSessionSelected( QAction * )) );
+	         SLOT(slotSessionSelected()) );
+
+	sessGroup = new QActionGroup( this );
 	insertSessions();
 
 	if (curPlugin < 0) {
@@ -419,7 +421,7 @@ KGreeter::insertSessions()
 	putSession( "failsafe", i18n("Failsafe"), false, "failsafe" );
 	qSort( sessionTypes );
 	for (int i = 0; i < sessionTypes.size() && !sessionTypes[i].hid; i++) {
-		sessionTypes[i].action = sessMenu->addAction( sessionTypes[i].name );
+		sessionTypes[i].action = sessGroup->addAction( sessionTypes[i].name );
 		sessionTypes[i].action->setData( i );
 		sessionTypes[i].action->setCheckable( true );
 		switch (sessionTypes[i].prio) {
@@ -427,6 +429,7 @@ KGreeter::insertSessions()
 		case 2: nNormals++; break;
 		}
 	}
+	sessMenu->addActions( sessGroup->actions() );
 }
 
 void
@@ -466,16 +469,9 @@ KGreeter::slotUserClicked( QListWidgetItem *item )
 }
 
 void
-KGreeter::slotSessionSelected( QAction *action )
+KGreeter::slotSessionSelected()
 {
-	if (action != curSel) {
-		if (curSel)
-			curSel->setChecked( false );
-		if (action)
-			action->setChecked( true );
-		curSel = action;
-		verify->gplugActivity();
-	}
+	verify->gplugActivity();
 }
 
 void
@@ -558,7 +554,7 @@ KGreeter::slotLoadPrevWM()
 					setPrevWM( sessionTypes[i].action );
 					return;
 				}
-			if (!curSel)
+			if (!sessGroup->checkedAction())
 				KFMsgBox::box( this, sorrybox,
 				               i18n("Your saved session type '%1' is not valid any more.\n"
 				                    "Please select a new one, otherwise 'default' will be used.", sess ) );
@@ -606,7 +602,8 @@ KGreeter::verifyClear()
 {
 	curUser.clear();
 	slotUserEntered();
-	slotSessionSelected( 0 );
+	if (QAction *curSel = sessGroup->checkedAction())
+		curSel->setChecked( false );
 }
 
 void
@@ -617,7 +614,7 @@ KGreeter::verifyOk()
 		                         dName :
 		                         dName + '_' + verify->pluginName(),
 		                      verify->getEntity() );
-	if (curSel) {
+	if (QAction *curSel = sessGroup->checkedAction()) {
 		gSendInt( G_PutDmrc );
 		gSendStr( "Session" );
 		gSendStr( sessionTypes[curSel->data().toInt()].type.toUtf8() );
@@ -692,7 +689,9 @@ KStdGreeter::KStdGreeter()
 		complainLabel->setAlignment( Qt::AlignCenter );
 		complainLabel->setFont( *_failFont );
 		QPalette p;
-		p.setColor( QPalette::WindowText, Qt::red );
+		p.setBrush( QPalette::WindowText,
+			KColorScheme( QPalette::Active, KColorScheme::Window )
+				.foreground( KColorScheme::NegativeText ) );
 		complainLabel->setPalette( p );
 		inner_box->addWidget( complainLabel );
 	}
