@@ -31,6 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/kdmthemer.h"
 #include "themer/kdmitem.h"
 
+#include <KColorScheme>
 #include <kguiitem.h>
 #include <klibrary.h>
 #include <klocale.h>
@@ -108,14 +109,16 @@ KGVerify::getPlugMenu()
 		uint np = pluginList.count();
 		if (np > 1) {
 			plugMenu = new QMenu( parent );
+			QActionGroup *plugGroup = new QActionGroup( parent );
 			connect( plugMenu, SIGNAL(triggered( QAction * )),
 			         SLOT(slotPluginSelected( QAction * )) );
 			for (uint i = 0; i < np; i++) {
 				int pid = pluginList[i];
-				greetPlugins[pid].action = plugMenu->addAction( i18n(greetPlugins[pid].info->name) );
+				greetPlugins[pid].action = plugGroup->addAction( i18n(greetPlugins[pid].info->name) );
 				greetPlugins[pid].action->setData( i );
 				greetPlugins[pid].action->setCheckable( true );
 			}
+			plugMenu->addActions( plugGroup->actions() );
 		}
 	}
 	return plugMenu;
@@ -194,7 +197,6 @@ KGVerify::slotPluginSelected( QAction *action )
 		return;
 	int id = action->data().toInt();
 	if (id != curPlugin) {
-		greetPlugins[pluginList[curPlugin]].action->setChecked( false );
 		parent->setUpdatesEnabled( false );
 		debug( "delete %s\n", pName.data() );
 		delete greet;
@@ -1025,7 +1027,9 @@ KGStdVerify::updateStatus()
 				failedLabel->clear();
 				break;
 			case 3:
-				p.setColor( QPalette::WindowText, Qt::red );
+				p.setBrush( QPalette::WindowText,
+					KColorScheme( QPalette::Active, KColorScheme::Window )
+						.foreground( KColorScheme::NegativeText ) );
 				failedLabel->setText( i18n("Warning: Caps Lock is on") );
 				break;
 			case 2:
