@@ -36,6 +36,7 @@
 #include <QFrame>
 #include <QDropEvent>
 #include <QMenu>
+#include <QtDBus/QtDBus>
 
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -1550,6 +1551,10 @@ bool TreeView::save()
        KMessageBox::sorry(this, "<qt>"+i18n("Menu changes could not be saved because of the following problem:")+"<br><br>"+
                                 m_menuFile->error()+"</qt>");
     }
+    QDBusMessage message =
+        QDBusMessage::createSignal("/kickoff", "org.kde.plasma", "reloadMenu");
+    QDBusConnection::sessionBus().send(message);
+
     return success;
 }
 
