@@ -38,6 +38,8 @@
 #include <KAuthorized>
 #include <KDesktopFile>
 #include <kservicetypetrader.h>
+#include <kmacroexpander.h>
+#include <kshell.h>
 
 #include <QtGui/QFrame>
 #include <QLabel>
@@ -122,17 +124,17 @@ LockProcess::LockProcess(bool child, bool useBlankOnly)
     QX11Info info;
     XGetWindowAttributes(QX11Info::display(), RootWindow(QX11Info::display(),
                                                          info.screen()), &rootAttr);
-    mRootWidth = rootAttr.width;
-    mRootHeight = rootAttr.height;
+    kapp->desktop(); // make Qt set its event mask on the root window first
     XSelectInput( QX11Info::display(), QX11Info::appRootWindow(),
                   SubstructureNotifyMask | rootAttr.your_event_mask );
+    setGeometry(0, 0, rootAttr.width, rootAttr.height);
 
     // virtual root property
     gXA_VROOT = XInternAtom (QX11Info::display(), "__SWM_VROOT", False);
     gXA_SCREENSAVER_VERSION = XInternAtom (QX11Info::display(), "_SCREENSAVER_VERSION", False);
 
     connect(&mHackProc, SIGNAL(processExited(K3Process *)),
-            SLOT(hackExited(K3Process *)));
+            SLOT(hackExited()));
 
     mSuspendTimer.setSingleShot(true);
     connect(&mSuspendTimer, SIGNAL(timeout()), SLOT(suspend()));
@@ -459,7 +461,7 @@ void LockProcess::createSaverWindow()
     Window w = XCreateWindow( x11Info().display(), RootWindow( x11Info().display(), x11Info().screen()),
         x(), y(), width(), height(), 0, depth, InputOutput, visual, flags, &attrs );
 
-    create( w );
+    create( w, false, true );
 
     // Some xscreensaver hacks check for this property
     const char *version = "KDE 4.0";
@@ -478,10 +480,11 @@ void LockProcess::createSaverWindow()
 
     // set NoBackground so that the saver can capture the current
     // screen state if necessary
+    setAttribute(Qt::WA_PaintOnScreen, true);
     setAttribute(Qt::WA_NoSystemBackground, true);
+    setAttribute(Qt::WA_PaintOutsidePaintEvent, true); // for bitBlt in resume()
 
     setCursor( Qt::BlankCursor );
-    setGeometry(0, 0, mRootWidth, mRootHeight);
 
     kDebug(1204) << "Saver window Id: " << winId();
 }
@@ -794,60 +797,27 @@ bool LockProcess::startLock()
 
 bool LockProcess::startHack()
 {
-    if (mSaverExec.isEmpty())
+    kDebug(1204) << "Starting hack:" << mSaverExec;
+
+    if (mSaverExec.isEmpty() || mForbidden)
     {
+        hackExited();
         return false;
     }
 
-    if (mHackProc.isRunning())
+    QHash<QChar, QString> keyMap;
+    keyMap.insert('w', QString::number(winId()));
+    mHackProc << KShell::splitArgs(KMacroExpander::expandMacrosShellQuote(mSaverExec, keyMap));
+
+    if (mHackProc.start())
     {
-        stopHack();
-    }
-
-    mHackProc.clearArguments();
-
-    QTextStream ts(&mSaverExec, QIODevice::ReadOnly);
-    QString word;
-    ts >> word;
-    QString path = KStandardDirs::findExe(word);
-
-    if (!path.isEmpty())
-    {
-        mHackProc << path;
-
-        kDebug(1204) << "Starting hack: " << path;
-
-        while (!ts.atEnd())
-        {
-            ts >> word;
-            if (word == "%w")
-            {
-                word = word.setNum(winId());
-            }
-            mHackProc << word;
-        }
-
-        if (!mForbidden)
-        {
-
-            if (mHackProc.start() == true)
-            {
 #ifdef HAVE_SETPRIORITY
-                setpriority(PRIO_PROCESS, mHackProc.pid(), mPriority);
+        setpriority(PRIO_PROCESS, mHackProc.pid(), mPriority);
 #endif
-                //bitBlt(this, 0, 0, &mOriginal);
-                return true;
-            }
-        }
-        else
-        {
-            // we aren't allowed to start the specified screensaver either because it didn't run for some reason
-	    // according to the kiosk restrictions forbid it
-            QPalette palette;
-            palette.setColor(backgroundRole(), Qt::black);
-            setPalette(palette);
-        }
+        return true;
     }
+
+    hackExited();
     return false;
 }
 
@@ -867,13 +837,12 @@ void LockProcess::stopHack()
 
 //---------------------------------------------------------------------------
 //
-void LockProcess::hackExited(K3Process *)
+void LockProcess::hackExited()
 {
 	// Hack exited while we're supposed to be saving the screen.
 	// Make sure the saver window is black.
-    QPalette palette;
-    palette.setColor(backgroundRole(), Qt::black);
-    setPalette(palette);
+    XSetWindowBackground(QX11Info::display(), winId(), 0);
+    XClearWindow(QX11Info::display(), winId());
 }
 
 void LockProcess::suspend()
@@ -895,6 +864,7 @@ void LockProcess::resume( bool force )
     {
         XForceScreenSaver(QX11Info::display(), ScreenSaverReset );
         bitBlt( this, 0, 0, &mSavedScreen );
+        mSavedScreen = QPixmap();
         QApplication::syncX();
         mHackProc.kill(SIGCONT);
     }
