@@ -5,8 +5,9 @@
     Copyright (c) 2006 John Tapsell <tapsell@kde.org>
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation
+    modify it under the terms of the GNU General Public
+    License version 2 or at your option version 3 as published by
+    the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -56,6 +57,7 @@ KSignalPlotter::KSignalPlotter( QWidget *parent)
   QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
   sizePolicy.setHeightForWidth(false);
   setSizePolicy( sizePolicy );
+  setAttribute( Qt::WA_OpaquePaintEvent );
 
   mShowVerticalLines = true;
   mVerticalLinesColor = QColor("black");
@@ -83,10 +85,10 @@ KSignalPlotter::~KSignalPlotter()
 }
 
 QString KSignalPlotter::translatedUnit() const {
-  return mUnit;
+  return mTranslatedUnit;
 }
-void KSignalPlotter::setTranslatedUnit(const QString &unit) {
-  mUnit= unit;
+void KSignalPlotter::setTranslatedUnit(const QString &translatedUnit) {
+  mTranslatedUnit= translatedUnit;
 }
 
 
@@ -102,6 +104,19 @@ void KSignalPlotter::addBeam( const QColor &color )
   mBeamColorsDark.append(color.darker(150));
 }
 
+QColor KSignalPlotter::beamColor( int index ) {
+  return mBeamColors[ index ];
+}
+
+void KSignalPlotter::setBeamColor( int index, QColor color ) {
+  mBeamColors[ index ] = color;
+  mBeamColorsDark[ index ] = color.darker(150);
+}
+
+int KSignalPlotter::numBeams() {
+  return mBeamColors.count();
+}
+
 void KSignalPlotter::addSample( const QList<double>& sampleBuf )
 {
   if(mSamples < 4) {
@@ -173,11 +188,6 @@ void KSignalPlotter::changeRange( double min, double max )
   calculateNiceRange();
 }
 
-QList<QColor> &KSignalPlotter::beamColors()
-{
-  return mBeamColors;
-}
-
 void KSignalPlotter::removeBeam( uint pos )
 {
   if(pos >= (uint)mBeamColors.size()) return;
@@ -199,16 +209,16 @@ void KSignalPlotter::setScaleDownBy( double value )
 }
 double KSignalPlotter::scaleDownBy() const { return mScaleDownBy; }
 
-void KSignalPlotter::setTitle( const QString &title )
+void KSignalPlotter::setTranslatedTitle( const QString &translatedTitle )
 {
-  if(mTitle == title) return;
-  mTitle = title;
+  if(mTranslatedTitle == translatedTitle) return;
+  mTranslatedTitle = translatedTitle;
   mBackgroundImage = QImage(); //we changed a paint setting, so reset the cache
 }
 
-QString KSignalPlotter::title() const
+QString KSignalPlotter::translatedTitle() const
 {
-  return mTitle;
+  return mTranslatedTitle;
 }
 
 void KSignalPlotter::setUseAutoRange( bool value )
@@ -426,13 +436,10 @@ void KSignalPlotter::setThinFrame( bool set)
   mShowThinFrame = set;
   mBackgroundImage = QImage(); //we changed a paint setting, so reset the cache
 }
+
 void KSignalPlotter::resizeEvent( QResizeEvent* )
 {
   Q_ASSERT( width() > 2 );
-//  mBackgroundImage = mBackgroundImage.scaled(width(), height()); //set to null.  If it's invalid, it will be rerendered.
-  if (testAttribute(Qt::WA_PendingResizeEvent)) {
-      return; // we'll be back here again in no time
-  }
 
   updateDataBuffers();
 }
@@ -602,7 +609,7 @@ void KSignalPlotter::calculateNiceRange()
     // Massage the range so that the grid shows some nice values.
     double step = mNiceRange / (mScaleDownBy*(mHorizontalLinesCount+1));
     int logdim = (int)floor( log10( step ) );
-    double dim = pow( 10, logdim ) / 2;
+    double dim = pow( (double)10.0, logdim ) / 2;
     int a = (int)ceil( step / dim );
     if(logdim >= 0)
         mPrecision = 0;
@@ -625,7 +632,7 @@ void KSignalPlotter::drawTopBarFrame(QPainter *p, int fullWidth, int seperatorX,
       p->setPen( Qt::NoPen);
 //      p->fillRect( 0, 0, fullWidth, height-1, QBrush(QColor(255,255,255,60)));
       p->setPen( mFontColor );
-      p->drawText(0, 1, seperatorX, height, Qt::AlignCenter, mTitle );
+      p->drawText(0, 1, seperatorX, height, Qt::AlignCenter, mTranslatedTitle );
       p->setPen( mHorizontalLinesColor );
       p->drawLine( seperatorX - 1, 1, seperatorX - 1, height-1 );
 }
@@ -922,7 +929,7 @@ void KSignalPlotter::drawAxisText(QPainter *p, int top, int h)
         value = mNiceMaxValue/mScaleDownBy - y * stepsize;
 
     QString number = KGlobal::locale()->formatNumber( value, mPrecision);
-    val = QString( "%1 %2" ).arg( number, mUnit );
+    val = QString( "%1 %2" ).arg( number, mTranslatedUnit );
     p->drawText( 6, y_coord - 3, val );
   }
 }
@@ -948,11 +955,11 @@ QString KSignalPlotter::lastValueAsString( int i) const
   double value = mBeamData.first()[i] / mScaleDownBy; //retrieve the newest value for this beam then scale it correct
   QString number = KGlobal::locale()->formatNumber( value, (value >= 100)?0:2);
 
-  if (mUnit == "%" || mUnit == "") {
-    return QString( "%1%2" ).arg(number, mUnit);
+  if (mTranslatedUnit == "%" || mTranslatedUnit == "") {
+    return QString( "%1%2" ).arg(number, mTranslatedUnit);
   }
   else {
-    return QString( "%1 %2" ).arg(number, mUnit);
+    return QString( "%1 %2" ).arg(number, mTranslatedUnit);
   }
 }
 #include "SignalPlotter.moc"
