@@ -4,8 +4,9 @@
     Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of version 2 of the GNU General Public
-    License as published by the Free Software Foundation.
+    modify it under the terms of the GNU General Public
+    License version 2 or at your option version 3 as published by
+    the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -55,6 +56,7 @@ WorkSheet::WorkSheet( QWidget *parent )
   mRows = mColumns = 0;
   mDisplayList = 0;
   mFileName = "";
+  mLocalProcessController = NULL;
 
   setAcceptDrops( true );
 }
@@ -118,6 +120,7 @@ bool WorkSheet::load( const QString &fileName )
   setUpdateInterval(interval);
 
   mTitle = element.attribute( "title");
+  mTranslatedTitle = i18n(mTitle.toLatin1());
   bool ok;
   mSharedSettings.locked = element.attribute( "locked" ).toUInt( &ok );
   if(!ok) mSharedSettings.locked = false;
@@ -288,19 +291,23 @@ void WorkSheet::setFileName( const QString &fileName )
   mFileName = fileName;
 }
 
-const QString& WorkSheet::fileName() const
+QString WorkSheet::fileName() const
 {
   return mFileName;
 }
 
 void WorkSheet::setTitle( const QString &title )
 {
-  kDebug() << "Set title " << title;
   mTitle = title;
+  mTranslatedTitle = i18n(mTitle.toLatin1());
   emit titleChanged(this);
 }
 
-const QString &WorkSheet::title() {
+QString WorkSheet::translatedTitle() const {
+  return mTranslatedTitle;
+}
+
+QString WorkSheet::title() const {
   return mTitle;
 }
 
@@ -352,7 +359,11 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const QString &hostName,
       newDisplay = new SensorLogger( this, sensorDescr, &mSharedSettings );
     }
     else if ( sensorType == "table" ) {
-      newDisplay = new ProcessController( this, sensorDescr, &mSharedSettings);
+      if(!mLocalProcessController && (hostName.isEmpty() || hostName == "localhost")) {
+        mLocalProcessController = new ProcessController( this, sensorDescr, &mSharedSettings);
+	newDisplay = mLocalProcessController;
+      } else 
+        newDisplay = new ProcessController( this, sensorDescr, &mSharedSettings);
     }
     else {
       kDebug(1215) << "Unknown sensor type: " <<  sensorType;
@@ -371,7 +382,7 @@ KSGRD::SensorDisplay *WorkSheet::addDisplay( const QString &hostName,
 void WorkSheet::settings()
 {
   WorkSheetSettings dlg( this, mSharedSettings.locked );
-  dlg.setSheetTitle( mTitle );
+  dlg.setSheetTitle( mTranslatedTitle );
   dlg.setInterval( updateInterval() );
 
   if(!mSharedSettings.locked) {
@@ -385,10 +396,12 @@ void WorkSheet::settings()
     if (!mSharedSettings.locked)
       resizeGrid( dlg.rows(), dlg.columns() );
 
-    if(mRows == 1 && mColumns ==1) {
-      mDisplayList[ 0 ][ 0 ]->setTitle(dlg.sheetTitle());
-    } else {
-      setTitle(dlg.sheetTitle());
+    if(mTranslatedTitle != dlg.sheetTitle()) { //Title has changed
+      if(mRows == 1 && mColumns ==1) {
+        mDisplayList[ 0 ][ 0 ]->setTitle(dlg.sheetTitle());
+      } else {
+        setTitle(dlg.sheetTitle());
+      }
     }
   }
 }
@@ -407,8 +420,10 @@ void WorkSheet::applyStyle()
 
 void WorkSheet::dragEnterEvent( QDragEnterEvent *event )
 {
-  if ( event->mimeData()->hasText() )
-    event->acceptProposedAction();
+  if ( !event->mimeData()->hasText() )
+    return;
+
+  event->acceptProposedAction();
 }
 
 void WorkSheet::dropEvent( QDropEvent *event )
@@ -431,6 +446,7 @@ void WorkSheet::dropEvent( QDropEvent *event )
 
   /* Find the sensor display that is supposed to get the drop
    * event and replace or add sensor. */
+  const QPoint globalPos = mapToGlobal( event->pos() );
   for ( uint r = 0; r < mRows; ++r ) {
     for ( uint c = 0; c < mColumns; ++c ) {
       const QSize displaySize = mDisplayList[ r ][ c ]->size();
@@ -440,7 +456,6 @@ void WorkSheet::dropEvent( QDropEvent *event )
       const QRect widgetRect = QRect( mDisplayList[ r ][ c ]->mapToGlobal( QPoint( 0, 0 ) ),
                                       mDisplayList[ r ][ c ]->mapToGlobal( displayPoint ) );
 
-      const QPoint globalPos = mapToGlobal( event->pos() );
 
       if ( widgetRect.contains( globalPos ) ) {
         addDisplay( hostName, sensorName, sensorType, sensorDescr, r, c );
@@ -475,7 +490,7 @@ bool WorkSheet::event( QEvent *e )
 bool WorkSheet::replaceDisplay( uint row, uint column, QDomElement& element )
 {
   QString classType = element.attribute( "class" );
-  KSGRD::SensorDisplay* newDisplay;
+  KSGRD::SensorDisplay* newDisplay = 0;
 
 
   if ( classType == "FancyPlotter" )
@@ -490,9 +505,13 @@ bool WorkSheet::replaceDisplay( uint row, uint column, QDomElement& element )
     newDisplay = new LogFile( 0, i18n("Dummy"), &mSharedSettings );
   else if ( classType == "SensorLogger" )
     newDisplay = new SensorLogger( 0, i18n("Dummy"), &mSharedSettings );
-  else if ( classType == "ProcessController" )
-    newDisplay = new ProcessController( 0, i18n("Dummy"), &mSharedSettings);
-  else {
+  else if ( classType == "ProcessController" ) {
+    if(!mLocalProcessController) {
+      kDebug() << "Found process controller"; 
+      mLocalProcessController = new ProcessController( 0, i18n("Dummy"), &mSharedSettings);
+      newDisplay = mLocalProcessController;
+    }
+  } else {
     kDebug(1215) << "Unknown class " <<  classType;
     return false;
   }
@@ -513,6 +532,8 @@ void WorkSheet::replaceDisplay( uint row, uint column, KSGRD::SensorDisplay* new
 {
   // remove the old display && sensor frame at this location
   if ( mDisplayList[ row ][ column ] ) {
+    if(mDisplayList[ row ][ column ] == mLocalProcessController) 
+      mLocalProcessController = NULL;
     if ( qstrcmp( mDisplayList[ row ][ column ]->parent()->metaObject()->className(), "SensorFrame" ) == 0 ) {
       delete mDisplayList[ row ][ column ]->parent(); // destroys the child (display) as well
     } else {
@@ -533,7 +554,7 @@ void WorkSheet::replaceDisplay( uint row, uint column, KSGRD::SensorDisplay* new
 
   mGridLayout->addWidget( mDisplayList[ row ][ column ], row, column );
   if(mRows == 1 && mColumns == 1) {  //if there's only item, the tab's title should be the widget's title
-    connect( newDisplay, SIGNAL(changeTitle(const QString&)), SLOT(setTitle(const QString&)));
+    connect( newDisplay, SIGNAL(titleChanged(const QString&)), SLOT(setTitle(const QString&)));
     setTitle(newDisplay->title());
   }
   if ( isVisible() ) {
@@ -547,6 +568,9 @@ void WorkSheet::removeDisplay( KSGRD::SensorDisplay *display )
 {
   if ( !display )
     return;
+  
+  if(display == mLocalProcessController) 
+    mLocalProcessController = NULL;
 
   for ( uint r = 0; r < mRows; ++r )
     for ( uint c = 0; c < mColumns; ++c )
@@ -689,6 +713,12 @@ QString WorkSheet::currentDisplayAsXML()
   return doc.toString();
 }
 
+void WorkSheet::changeEvent( QEvent * event ) {
+  if (event->type() == QEvent::LanguageChange) {
+    setTitle(mTitle);  //retranslate
+  }
+}
+
 void WorkSheet::setUpdateInterval( unsigned int secs)
 {
   if(secs == 0)
