@@ -1,3 +1,3 @@
 #ifndef KSYSGUARD_VERSION
 #define KSYSGUARD_VERSION "4"
-#endif // KSYSGUARD_VERSION
+#endif
