@@ -28,6 +28,7 @@ KSysTrayCmd::KSysTrayCmd()
     isVisible(true), lazyStart( false ), noquit( false ), quitOnHide( false ), onTop(false), ownIcon(false),
     win(0), client(0), top(0), left(0)
 {
+  connect(this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(mousePressEvent(QSystemTrayIcon::ActivationReason)));
   refresh();
 }
 
@@ -224,7 +225,7 @@ void KSysTrayCmd::execContextMenu( const QPoint &pos )
     KMenu *menu = new KMenu();
     menu->addTitle( icon(), i18n( "KSysTrayCmd" ) );
     QAction * hideShowId = menu->addAction( isVisible ? i18n( "&Hide" ) : i18n( "&Restore" ) );
-    QAction * undockId = menu->addAction( KIcon("close"), i18n( "&Undock" ) );
+    QAction * undockId = menu->addAction( KIcon("dialog-close"), i18n( "&Undock" ) );
     QAction * quitId = menu->addAction( KIcon("application-exit"), i18n( "&Quit" ) );
 
     QAction * cmd = menu->exec( pos );
@@ -281,10 +282,10 @@ void KSysTrayCmd::windowChanged( WId w )
 // Tray icon event handlers
 //
 
-void KSysTrayCmd::mousePressEvent( QMouseEvent *e )
+void KSysTrayCmd::mousePressEvent( QSystemTrayIcon::ActivationReason reason )
 {
-  if ( e->button() == Qt::RightButton )
-    execContextMenu( e->globalPos() );
+  if ( reason == QSystemTrayIcon::Context )
+    execContextMenu( QCursor::pos() );
   else if ( lazyStart && ( !hasRunningClient() ) )
   {
     start();
@@ -296,7 +297,7 @@ void KSysTrayCmd::mousePressEvent( QMouseEvent *e )
     ri.closeWindowRequest( win );
     isVisible=false;
   }
-  else
+  else if ( reason == QSystemTrayIcon::Trigger )
     toggleWindow();
 }
 
