@@ -1,13 +1,23 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 /*
 
@@ -495,8 +505,9 @@ void Workspace::setShouldGetFocus( Client* c )
     }
 
 // focus_in -> the window got FocusIn event
-// session_active -> the window was active when saving session
-bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in )
+// ignore_desktop - call comes from _NET_ACTIVE_WINDOW message, don't refuse just because of window
+//     is on a different desktop
+bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in, bool ignore_desktop )
     {
     // options->focusStealingPreventionLevel :
     // 0 - none    - old KWin behaviour, new windows always get focus
@@ -528,7 +539,7 @@ bool Workspace::allowClientActivation( const Client* c, Time time, bool focus_in
         return true;
     if( level == 4 ) // extreme
         return false;
-    if( !c->isOnCurrentDesktop())
+    if( !ignore_desktop && !c->isOnCurrentDesktop())
         return false; // allow only with level == 0
     if( c->ignoreFocusStealing())
         return true;
