@@ -1133,7 +1133,7 @@ void Client::killProcess( bool ask, Time timestamp )
         connect( process_killer, SIGNAL( finished( int, QProcess::ExitStatus )), SLOT( processKillerExited()));
         process_killer->start( KStandardDirs::findExe( "kwin_killer_helper" ),
             QStringList() << "--pid" << QByteArray().setNum( (unsigned)pid ) << "--hostname" << machine
-            << "--windowname" << caption().toUtf8()
+            << "--windowname" << caption()
             << "--applicationname" << resourceClass()
             << "--wid" << QString::number( window() )
             << "--timestamp" << QString::number( timestamp ));
