@@ -28,25 +28,7 @@
 
 #include <math.h>
 
-// alphaBlendColors Copyright 2003 Sandro Giessl <ceebx@users.sourceforge.net>
-// DEPRECATED (use KColorUtils::mix to the extent we still need such a critter)
-QColor alphaBlendColors(const QColor &bgColor, const QColor &fgColor, const int a)
-{
-
-    // normal button...
-    QRgb rgb = bgColor.rgb();
-    QRgb rgb_b = fgColor.rgb();
-    int alpha = a;
-    if(alpha>255) alpha = 255;
-    if(alpha<0) alpha = 0;
-    int inv_alpha = 255 - alpha;
-
-    QColor result  = QColor( qRgb(qRed(rgb_b)*inv_alpha/255 + qRed(rgb)*alpha/255,
-                                  qGreen(rgb_b)*inv_alpha/255 + qGreen(rgb)*alpha/255,
-                                  qBlue(rgb_b)*inv_alpha/255 + qBlue(rgb)*alpha/255) );
-
-    return result;
-}
+const double OxygenHelper::_shadowGain = 1.5;
 
 // NOTE: OxygenStyleHelper needs to use a KConfig from its own KComponentData
 // Since the ctor order causes a SEGV if we try to pass in a KConfig here from
@@ -93,7 +75,9 @@ bool OxygenHelper::lowThreshold(const QColor &color)
 
 QColor OxygenHelper::alphaColor(QColor color, double alpha)
 {
-    color.setAlphaF(alpha);
+    if (alpha >= 1.0)
+        return color;
+    color.setAlphaF(qMax(0.0, alpha) * color.alphaF());
     return color;
 }
 
@@ -185,7 +169,7 @@ QPixmap OxygenHelper::radialGradient(const QColor &color, int width)
 
     if (!pixmap)
     {
-        width /= 2;
+//        width /= 2;
         pixmap = new QPixmap(width, 64);
         pixmap->fill(QColor(0,0,0,0));
         QColor radialColor = backgroundRadialColor(color);
@@ -201,7 +185,7 @@ QPixmap OxygenHelper::radialGradient(const QColor &color, int width)
 
         QPainter p(pixmap);
         p.scale(width/128.0,1);
-        p.fillRect(pixmap->rect(), gradient);
+        p.fillRect(QRect(0,0,128,64), gradient);
 
         m_backgroundCache.insert(key, pixmap);
     }
@@ -219,7 +203,7 @@ void OxygenHelper::drawShadow(QPainter &p, const QColor &color, int size) const
     for (int i = 0; i < 8; i++) { // sinusoidal gradient
         double k1 = (k0 * double(8 - i) + double(i)) * 0.125;
         double a = (cos(3.14159 * i * 0.125) + 1.0) * 0.25;
-        shadowGradient.setColorAt(k1, alphaColor(color, a));
+        shadowGradient.setColorAt(k1, alphaColor(color, a * _shadowGain));
     }
     shadowGradient.setColorAt(1.0, alphaColor(color, 0.0));
     p.setBrush(shadowGradient);
@@ -318,3 +302,137 @@ QPixmap OxygenHelper::windecoButton(const QColor &color, int size)
 
     return *pixmap;
 }
+
+QPixmap OxygenHelper::glow(const QColor &color, int size, int rsize)
+{
+    QPixmap pixmap(rsize, rsize);
+    pixmap.fill(QColor(0,0,0,0));
+
+    QPainter p(&pixmap);
+    p.setRenderHints(QPainter::Antialiasing);
+    p.setPen(Qt::NoPen);
+    p.setWindow(0,0,size,size);
+
+    QRectF r(0, 0, size, size);
+    double m = double(size)*0.5;
+
+    const double width = 3.0;
+    const double bias = _glowBias * double(size) / double(rsize);
+    double k0 = (m-width+bias) / m;
+    QRadialGradient glowGradient(m, m, m);
+    for (int i = 0; i < 8; i++) { // inverse parabolic gradient
+        double k1 = (k0 * double(8 - i) + double(i)) * 0.125;
+        double a = 1.0 - sqrt(i * 0.125);
+        glowGradient.setColorAt(k1, alphaColor(color, a));
+    }
+    glowGradient.setColorAt(1.0, alphaColor(color, 0.0));
+
+    // glow
+    p.setBrush(glowGradient);
+    p.drawEllipse(r);
+
+    // mask
+    p.setCompositionMode(QPainter::CompositionMode_DestinationOut);
+    p.setBrush(QBrush(Qt::black));
+    p.drawEllipse(r.adjusted(width, width, -width, -width));
+
+    p.end();
+
+    return pixmap;
+}
+
+QPixmap OxygenHelper::windecoButtonFocused(const QColor &color, const QColor &glowColor, int size)
+{
+    quint64 key = (quint64(glowColor.rgba()) << 32) | size;
+    QPixmap *pixmap = m_windecoButtonCache.object(key);
+
+    if (!pixmap)
+    {
+        pixmap = new QPixmap(size*3, size*3);
+        pixmap->fill(QColor(0,0,0,0));
+
+        QPainter p(pixmap);
+        p.setRenderHints(QPainter::Antialiasing);
+        p.setPen(Qt::NoPen);
+        p.setWindow(0,0,21,21);
+
+        // slab
+        QPixmap slabPixmap = windecoButton(color, size);
+        p.drawPixmap(0, 0, slabPixmap);
+
+        // glow
+        QPixmap gp = glow(glowColor, 21, size*3);
+        p.drawPixmap(0, 0, gp);
+
+        p.end();
+
+        m_windecoButtonCache.insert(key, pixmap);
+    }
+    return *pixmap;
+}
+
+void OxygenHelper::drawFloatFrame(QPainter *p, const QRect r, const QColor &color) const
+{
+    p->setRenderHint(QPainter::Antialiasing);
+    QRect frame = r;
+    frame.adjust(1,1,-1,-1);
+    int x,y,w,h;
+    frame.getRect(&x, &y, &w, &h);
+
+    QColor light = calcLightColor(backgroundTopColor(color));
+    QColor dark = calcDarkColor(color);
+
+    p->setBrush(Qt::NoBrush);
+
+    if (0) { // TODO make option
+        QColor shadow = calcShadowColor(color); // wrong, use kwin shadow color
+        p->setPen(alphaColor(shadow, 0.1));
+        p->drawLine(QPointF(x+4, y-0.5), QPointF(x+w-4, y-0.5));
+        p->drawArc(QRectF(x-0.5, y-0.5, 11, 11),90*16, 90*16);
+        p->drawArc(QRectF(x+w-11+0.5, y-0.5, 11, 11), 0, 90*16);
+        p->setPen(alphaColor(shadow, 0.3));
+        p->drawLine(QPointF(x-0.5, y+4), QPointF(x-0.5, y+h));
+        p->drawLine(QPointF(x+w+0.5, y+4), QPointF(x+w+0.5, y+h));
+        p->setPen(alphaColor(shadow, 0.4));
+        p->drawArc(QRectF(0.5, y+h-11+0.5, 11, 11),180*16, 90*16);
+        p->drawArc(QRectF(x+w-11+0.5, y+h-11+0.5, 11, 11),270*16, 90*16);
+        p->setPen(alphaColor(shadow, 0.55));
+        p->drawLine(QPointF(x+4, y+h+0.5), QPointF(x+w-4, y+h+0.5));
+    }
+    else if (1) { // TODO make option
+        QColor shadow = KColorUtils::darken(color, 0.0, 0.0); // fully desaturate
+        p->setPen(KColorUtils::darken(shadow, 0.1));
+        p->drawLine(QPointF(x+4, y-0.5), QPointF(x+w-4, y-0.5));
+        p->drawArc(QRectF(x-0.5, y-0.5, 11, 11),90*16, 90*16);
+        p->drawArc(QRectF(x+w-11+0.5, y-0.5, 11, 11), 0, 90*16);
+        p->setPen(KColorUtils::darken(shadow, 0.3));
+        p->drawLine(QPointF(x-0.5, y+4), QPointF(x-0.5, y+h-4));
+        p->drawLine(QPointF(x+w+0.5, y+4), QPointF(x+w+0.5, y+h-4));
+        p->setPen(KColorUtils::darken(shadow, 0.4));
+        p->drawArc(QRectF(0.5, y+h-11+0.5, 11, 11),180*16, 90*16);
+        p->drawArc(QRectF(x+w-11+0.5, y+h-11+0.5, 11, 11),270*16, 90*16);
+        p->setPen(KColorUtils::darken(shadow, 0.55));
+        p->drawLine(QPointF(x+4, y+h+0.5), QPointF(x+w-4, y+h+0.5));
+    }
+
+    p->setPen(QPen(light, 1.2));
+    p->drawLine(QPointF(x+4, y+0.6), QPointF(x+w-4, y+0.6));
+    QLinearGradient lg = QLinearGradient(0.0, 1.5, 0.0, 4.5);
+    lg.setColorAt(0, light);
+    light = calcLightColor(backgroundBottomColor(color));
+    lg.setColorAt(1, light);
+    p->setPen(QPen(lg, 1.2));
+    p->drawArc(QRectF(x+0.6, y+0.6, 9, 9),90*16, 90*16);
+    p->drawArc(QRectF(x+w-9-0.6, y+0.6, 9, 9), 0, 90*16);
+    p->drawLine(QPointF(x+0.6, y+4), QPointF(x+0.6, y+h-4));
+    p->drawLine(QPointF(x+w-0.6, y+4), QPointF(x+w-0.6, y+h-4));
+
+    lg = QLinearGradient(0.0, y+h-4.5, 0.0, y+h-0.5);
+    lg.setColorAt(0, light);
+    lg.setColorAt(1, dark);
+    p->setPen(QPen(lg, 1.2));
+    p->drawArc(QRectF(x+0.6, y+h-9-0.6, 9, 9),180*16, 90*16);
+    p->drawArc(QRectF(x+w-9-0.6, y+h-9-0.6, 9, 9), 270*16, 90*16);
+    p->drawLine(QPointF(x+4, y+h-0.6), QPointF(x+w-4, y+h-0.6));
+    return;
+}
