@@ -29,9 +29,7 @@
 #include <QtGui/QLinearGradient>
 #include <QtCore/QCache>
 
-// alphaBlendColors Copyright 2003 Sandro Giessl <ceebx@users.sourceforge.net>
-// DEPRECATED
-QColor alphaBlendColors(const QColor &backgroundColor, const QColor &foregroundColor, const int alpha);
+#define _glowBias 0.9 // not likely to be configurable
 
 // WARNING - OxygenHelper must be a K_GLOBAL_STATIC!
 class OxygenHelper
@@ -64,9 +62,15 @@ public:
     QLinearGradient decoGradient(const QRect &r, const QColor &color);
 
     QPixmap windecoButton(const QColor &color, int size = 7);
+    QPixmap windecoButtonFocused(const QColor &color, const QColor &glowColor, int size);
+
+    void drawFloatFrame(QPainter *p, const QRect r, const QColor &color) const;
 
 protected:
     void drawShadow(QPainter&, const QColor&, int size) const;
+    static QPixmap glow(const QColor&, int size, int rsize);
+
+    static const double _shadowGain;
 
     KComponentData _componentData;
     KSharedConfigPtr _config;
