@@ -3,7 +3,7 @@
 // -------------------
 // Oxygen window decoration for KDE. Buttons.
 // -------------------
-// Copyright (c) 2006, 2007 Riccardo Iaconelli <ruphy@fsfe.org>
+// Copyright (c) 2006, 2007 Riccardo Iaconelli <riccardo@kde.org>
 // Copyright (c) 2006, 2007 Casper Boemann <cbr@boemann.dk>
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -31,18 +31,16 @@
 
 #include <kdecoration.h>
 #include <kglobal.h>
+#include <KColorUtils>
+#include <kdebug.h>
+#include <KColorScheme>
 
 #include "oxygenclient.h"
 #include "oxygenbutton.h"
 #include "oxygen.h"
-#include "definitions.cpp"
-#include "lib/helper.h"
 
 namespace Oxygen
 {
-#ifndef KDE_USE_FINAL
-K_GLOBAL_STATIC_WITH_ARGS(OxygenHelper, globalHelper, ("OxygenDeco"))
-#endif
 // class OxygenClient;
 /*
 extern int BUTTONSIZE;
@@ -58,12 +56,14 @@ extern int DECOSIZE;*/
 // ---------------
 // Constructor
 
-OxygenButton::OxygenButton(OxygenClient *parent,
+OxygenButton::OxygenButton(OxygenClient &parent,
                              const QString& tip, ButtonType type)
-    : KCommonDecorationButton((::ButtonType)type,(KCommonDecoration*) parent)
+    : KCommonDecorationButton((::ButtonType)type, &parent)
     , client_(parent)
+    , helper_(parent.helper_)
     , type_(type)
     , lastmouse_(0)
+    , colorCacheInvalid_(true)
 {
     setAutoFillBackground(false);
     setAttribute(Qt::WA_OpaquePaintEvent, false);
@@ -76,6 +76,28 @@ OxygenButton::~OxygenButton()
 {
 }
 
+//declare function from oxygenclient.cpp
+QColor reduceContrast(const QColor &c0, const QColor &c1, double t);
+
+
+QColor OxygenButton::buttonDetailColor(const QPalette &palette)
+{
+    if (client_.isActive())
+        return palette.color(QPalette::Active, QPalette::ButtonText);
+    else {
+        if (colorCacheInvalid_) {
+            QColor ab = palette.color(QPalette::Active, QPalette::Button);
+            QColor af = palette.color(QPalette::Active, QPalette::ButtonText);
+            QColor nb = palette.color(QPalette::Inactive, QPalette::Button);
+            QColor nf = palette.color(QPalette::Inactive, QPalette::ButtonText);
+
+            colorCacheInvalid_ = false;
+            cachedButtonDetailColor_ = reduceContrast(nb, nf, qMax(qreal(2.5), KColorUtils::contrastRatio(ab, KColorUtils::mix(ab, af, 0.4))));
+        }
+        return cachedButtonDetailColor_;
+    }
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // sizeHint()
 // ----------
@@ -93,11 +115,11 @@ QSize OxygenButton::sizeHint() const
 
 void OxygenButton::enterEvent(QEvent *e)
 {
-    // if we wanted to do mouseovers, we would keep track of it here
+    KCommonDecorationButton::enterEvent(e);
     if (status_ != Oxygen::Pressed) {
         status_ = Oxygen::Hovered;
     }
-    QAbstractButton::enterEvent(e);
+    update();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -107,9 +129,10 @@ void OxygenButton::enterEvent(QEvent *e)
 
 void OxygenButton::leaveEvent(QEvent *e)
 {
+    KCommonDecorationButton::leaveEvent(e);
     // if we wanted to do mouseovers, we would keep track of it here
     status_ = Oxygen::Normal;
-    QAbstractButton::leaveEvent(e);
+    update();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -130,53 +153,85 @@ void OxygenButton::pressSlot()
 void OxygenButton::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
+    QPalette pal = palette(); // de-const-ify
 
     if (type_ == ButtonMenu) {
         // we paint the mini icon (which is 16 pixels high)
         int dx = (width() - 16) / 2;
         int dy = (height() - 16) / 2;
-        painter.drawPixmap(dx, dy, client_->icon().pixmap(16));
+        painter.drawPixmap(dx, dy, client_.icon().pixmap(16));
         return;
     }
 
-    QColor bg = globalHelper->backgroundTopColor(palette().window());
-    painter.drawPixmap(0, 0, globalHelper->windecoButton(palette().button()));
+    // Set palette to the right group.
+    // TODO - fix KWin to do this for us :-).
+    if (client_.isActive())
+        pal.setCurrentColorGroup(QPalette::Active);
+    else
+        pal.setCurrentColorGroup(QPalette::Inactive);
+
+    if(client_.maximizeMode() == OxygenClient::MaximizeRestore)
+        painter.translate(0,-1);
+
+    QColor bg = helper_.backgroundTopColor(pal.window());
+
+    QLinearGradient lg = helper_.decoGradient(QRect(4,4,13,13), buttonDetailColor(pal));
+
+    if(status_ == Oxygen::Hovered) {
+        if(type_ == ButtonClose) {
+            QColor color = KColorScheme(pal.currentColorGroup()).foreground(KColorScheme::NegativeText).color();
+            lg = helper_.decoGradient(QRect(4,4,13,13), color);
+            painter.drawPixmap(0, 0, helper_.windecoButtonFocused(pal.button(), color,7));
+        }
+        else{
+            QColor color = KColorScheme(pal.currentColorGroup()).decoration(KColorScheme::HoverColor).color();
+            painter.drawPixmap(0, 0, helper_.windecoButtonFocused(pal.button(), color, 7));
+        }
+    }
+    else
+        painter.drawPixmap(0, 0, helper_.windecoButton(pal.button()));
 
-    painter.translate(1.5,1.5);
     painter.setRenderHints(QPainter::Antialiasing);
     painter.setBrush(Qt::NoBrush);
-    QLinearGradient lg(0, 6, 0, 12);
-    lg.setColorAt(0.45, QColor(0,0,0,150));
-    lg.setColorAt(0.80, QColor(0,0,0,80));
-    painter.setPen(QPen(lg,2));
+    painter.setPen(QPen(lg, 2.2, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
     switch(type_)
     {
         case ButtonSticky:
-                    painter.drawPoint(9,9);
+            painter.drawPoint(QPointF(10.5,10.5));
             break;
         case ButtonHelp:
+            painter.translate(1.5, 1.5);
+            painter.drawArc(7,5,4,4,135*16, -180*16);
+            painter.drawArc(9,8,4,4,135*16,45*16);
+            painter.drawPoint(9,12);
             break;
         case ButtonMin:
-            painter.drawLine(6,8,9,11);
-            painter.drawLine(9,11,12,8);
+            painter.drawLine(QPointF( 7.5, 9.5), QPointF(10.5,12.5));
+            painter.drawLine(QPointF(10.5,12.5), QPointF(13.5, 9.5));
             break;
         case ButtonMax:
-            switch(client_->maximizeMode())
+            switch(client_.maximizeMode())
             {
                 case OxygenClient::MaximizeRestore:
                 case OxygenClient::MaximizeVertical:
                 case OxygenClient::MaximizeHorizontal:
-                    painter.drawLine(9,8,12,11);
-                    painter.drawLine(6,11,9,8);
+                    painter.drawLine(QPointF( 7.5,11.5), QPointF(10.5, 8.5));
+                    painter.drawLine(QPointF(10.5, 8.5), QPointF(13.5,11.5));
                     break;
                 case OxygenClient::MaximizeFull:
-                    painter.drawLine(6,9,12,9);
+                {
+                    painter.translate(1.5, 1.5);
+                    //painter.setBrush(lg);
+                    QPoint points[4] = {QPoint(9, 6), QPoint(12, 9), QPoint(9, 12), QPoint(6, 9)};
+                    //QPoint points[4] = {QPoint(9, 5), QPoint(13, 9), QPoint(9, 13), QPoint(5, 9)};
+                    painter.drawPolygon(points, 4);
                     break;
+                }
             }
             break;
         case ButtonClose:
-            painter.drawLine(6,6,12,12);
-            painter.drawLine(12,6,6,12);
+            painter.drawLine(QPointF( 7.5,7.5), QPointF(13.5,13.5));
+            painter.drawLine(QPointF(13.5,7.5), QPointF( 7.5,13.5));
             break;
         default:
             break;
