@@ -295,13 +295,7 @@ void Workspace::performCompositing()
         return;
         }
     // create a list of all windows in the stacking order
-    ToplevelList windows;
-    foreach( Client* c, stacking_order )
-        windows.append( c );
-    foreach( Unmanaged* c, unmanaged_stacking_order )
-        windows.append( c );
-    foreach( Deleted* c, deleted ) // TODO remember stacking order somehow
-        windows.append( c );
+    ToplevelList windows = rootStackingOrder();
     foreach( EffectWindow* c, static_cast< EffectsHandlerImpl* >( effects )->elevatedWindows())
         {
         Toplevel* t = static_cast< EffectWindowImpl* >( c )->window();
@@ -379,14 +373,20 @@ void Workspace::setupOverlay( Window w )
     assert( Extensions::shapeInputAvailable());
     XShapeCombineRectangles( display(), overlay, ShapeInput, 0, 0, NULL, 0, ShapeSet, Unsorted );
     if( w != None )
-        {
         XShapeCombineRectangles( display(), w, ShapeInput, 0, 0, NULL, 0, ShapeSet, Unsorted );
-        XMapWindow( display(), w );
-        }
-    XMapRaised( display(), overlay );
     XSelectInput( display(), overlay, VisibilityChangeMask );
     }
 
+void Workspace::showOverlay()
+    {
+    assert( overlay != None );
+    if( overlay_shown )
+        return;
+    XMapSubwindows( display(), overlay );
+    XMapWindow( display(), overlay );
+    overlay_shown = true;
+    }
+
 void Workspace::destroyOverlay()
     {
     if( overlay == None )
@@ -395,6 +395,7 @@ void Workspace::destroyOverlay()
     XCompositeReleaseOverlayWindow( display(), overlay );
 #endif
     overlay = None;
+    overlay_shown = false;
     }
 
 //****************************************
