@@ -1,13 +1,23 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
+Copyright (C) 2007 Christian Nitschkowski <christian.nitschkowski@kdemail.net>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "lookingglass.h"
 
@@ -15,9 +25,11 @@ License. See the file "COPYING" for the exact licensing terms.
 
 #include <kactioncollection.h>
 #include <kaction.h>
+#include <kconfiggroup.h>
 #include <klocale.h>
 #include <kdebug.h>
 
+#include <kmessagebox.h>
 
 namespace KWin
 {
@@ -31,7 +43,11 @@ LookingGlassEffect::LookingGlassEffect() : QObject(), ShaderEffect("lookingglass
     zoom = 1.0f;
     target_zoom = 1.0f;
 
-    KActionCollection* actionCollection = new KActionCollection( this );
+    KConfigGroup conf = EffectsHandler::effectConfig("LookingGlass");
+    actionCollection = new KActionCollection( this );
+    actionCollection->setConfigGlobal(true);
+    actionCollection->setConfigGroup("LookingGlass");
+
     KAction* a;
     a = static_cast< KAction* >( actionCollection->addAction( KStandardAction::ZoomIn, this, SLOT( zoomIn())));
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_Plus));
@@ -39,7 +55,16 @@ LookingGlassEffect::LookingGlassEffect() : QObject(), ShaderEffect("lookingglass
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_Minus));
     a = static_cast< KAction* >( actionCollection->addAction( KStandardAction::ActualSize, this, SLOT( toggle())));
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_0));
-    radius = 200; // TODO config option
+    initialradius = conf.readEntry("Radius", 200);
+    radius = initialradius;
+
+    kDebug(1212) << QString("Radius from config: %1").arg(radius) << endl;
+
+    actionCollection->readSettings();
+    }
+
+LookingGlassEffect::~LookingGlassEffect()
+    {
     }
 
 void LookingGlassEffect::toggle()
@@ -79,7 +104,7 @@ void LookingGlassEffect::prePaintScreen( ScreenPrePaintData& data, int time )
         else
             zoom = qMax( zoom * qMin( 1.0 - diff, 0.8 ), target_zoom );
         kDebug() << "zoom is now " << zoom;
-        radius = qBound(200.0, 200.0 * zoom, 500.0);
+        radius = qBound((double)initialradius, initialradius * zoom, 3.5*initialradius);
 
         if( zoom > 1.0f )
             {
@@ -99,7 +124,8 @@ void LookingGlassEffect::prePaintScreen( ScreenPrePaintData& data, int time )
     ShaderEffect::prePaintScreen( data, time );
     }
 
-void LookingGlassEffect::mouseChanged( const QPoint& pos, const QPoint& old, Qt::MouseButtons, Qt::KeyboardModifiers )
+void LookingGlassEffect::mouseChanged( const QPoint& pos, const QPoint& old, Qt::MouseButtons,
+    Qt::MouseButtons, Qt::KeyboardModifiers, Qt::KeyboardModifiers )
     {
     if( pos != old && isEnabled() )
         {
