@@ -1,22 +1,34 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
-Copyright (C) 2006 Lubos Lunak <l.lunak@kde.org>
+Copyright (C) 2007 Lubos Lunak <l.lunak@kde.org>
+Copyright (C) 2007 Christian Nitschkowski <christian.nitschkowski@kdemail.net>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
-#include <config-X11.h> // HAVE_OPENGL
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
+
+#include <kwinconfig.h>
 
 #include "magnifier.h"
 
 #include <kaction.h>
 #include <kactioncollection.h>
+#include <kconfiggroup.h>
 #include <kstandardaction.h>
 
-#ifdef HAVE_OPENGL
+#ifdef KWIN_HAVE_OPENGL_COMPOSITING
 #include <GL/gl.h>
 #endif
 
@@ -31,6 +43,8 @@ MagnifierEffect::MagnifierEffect()
     : zoom( 1 )
     , target_zoom( 1 )
     {
+    KConfigGroup conf = EffectsHandler::effectConfig("Magnifier");
+
     KActionCollection* actionCollection = new KActionCollection( this );
     KAction* a;
     a = static_cast< KAction* >( actionCollection->addAction( KStandardAction::ZoomIn, this, SLOT( zoomIn())));
@@ -39,7 +53,11 @@ MagnifierEffect::MagnifierEffect()
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_Minus));
     a = static_cast< KAction* >( actionCollection->addAction( KStandardAction::ActualSize, this, SLOT( toggle())));
     a->setGlobalShortcut(KShortcut(Qt::META + Qt::Key_0));
-    magnifier_size = QSize( 200, 200 ); // TODO config option
+
+    int width, height;
+    width = conf.readEntry("Width", 200);
+    height = conf.readEntry("Height", 200);
+    magnifier_size = QSize( width, height );
     }
 
 void MagnifierEffect::prePaintScreen( ScreenPrePaintData& data, int time )
@@ -63,7 +81,7 @@ void MagnifierEffect::paintScreen( int mask, QRegion region, ScreenPaintData& da
     effects->paintScreen( mask, region, data ); // paint normal screen
     if( zoom != 1.0 )
         { // paint magnifier
-// ## TODO this should be inside HAVE_OPENGL
+// ## TODO this should be inside KWIN_HAVE_OPENGL_COMPOSITING
         glPushAttrib( GL_ENABLE_BIT );
         QRect area = magnifierArea();
         glEnable( GL_SCISSOR_TEST );
@@ -142,7 +160,8 @@ void MagnifierEffect::toggle()
     effects->addRepaint( magnifierArea().adjusted( -FRAME_WIDTH, -FRAME_WIDTH, FRAME_WIDTH, FRAME_WIDTH ));
     }
 
-void MagnifierEffect::mouseChanged( const QPoint& pos, const QPoint& old, Qt::MouseButtons, Qt::KeyboardModifiers )
+void MagnifierEffect::mouseChanged( const QPoint& pos, const QPoint& old,
+    Qt::MouseButtons, Qt::MouseButtons, Qt::KeyboardModifiers, Qt::KeyboardModifiers )
     {
     if( pos != old && zoom != 1 )
         effects->addRepaint( magnifierArea( old ).adjusted( -FRAME_WIDTH, -FRAME_WIDTH, FRAME_WIDTH, FRAME_WIDTH ));
