@@ -1,13 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "minimizeanimation.h"
 
@@ -24,6 +33,7 @@ MinimizeAnimationEffect::MinimizeAnimationEffect()
 
 void MinimizeAnimationEffect::prePaintScreen( ScreenPrePaintData& data, int time )
     {
+    mActiveAnimations = mAnimationProgress.count();
     if( mActiveAnimations > 0 )
         // We need to mark the screen windows as transformed. Otherwise the
         //  whole screen won't be repainted, resulting in artefacts
@@ -58,9 +68,6 @@ void MinimizeAnimationEffect::prePaintWindow( EffectWindow* w, WindowPrePaintDat
             data.setTransformed();
             w->enablePainting( EffectWindow::PAINT_DISABLED_BY_MINIMIZE );
             }
-        else
-            // Animation just finished
-            mActiveAnimations--;
         }
 
     effects->prePaintWindow( w, data, time );
@@ -94,6 +101,7 @@ void MinimizeAnimationEffect::postPaintScreen()
     if( mActiveAnimations > 0 )
         // Repaint the workspace so that everything would be repainted next time
         effects->addRepaintFull();
+    mActiveAnimations = mAnimationProgress.count();
 
     // Call the next effect.
     effects->postPaintScreen();
@@ -104,7 +112,6 @@ void MinimizeAnimationEffect::windowMinimized( EffectWindow* w )
     if( !mAnimationProgress.contains(w) )
         {
         mAnimationProgress[w] = 0.0f;
-        mActiveAnimations++;
         }
     }
 
@@ -113,7 +120,6 @@ void MinimizeAnimationEffect::windowUnminimized( EffectWindow* w )
     if( !mAnimationProgress.contains(w) )
         {
         mAnimationProgress[w] = 1.0f;
-        mActiveAnimations++;
         }
     }
 
