@@ -67,10 +67,6 @@ PresentWindowsEffect::PresentWindowsEffect()
 
     effects->reserveElectricBorder( borderActivate );
     effects->reserveElectricBorder( borderActivateAll );
-
-#ifdef KWIN_HAVE_XRENDER_COMPOSITING
-    alphaFormat = XRenderFindStandardFormat( display(), PictStandardARGB32 );
-#endif
     }
 
 PresentWindowsEffect::~PresentWindowsEffect()
@@ -300,8 +296,6 @@ void PresentWindowsEffect::setActive(bool active)
     if( mActivated )
         {
         mWindowData.clear();
-        effectActivated();
-        mActiveness = 0;
         windowFilter.clear();
         mWindowsToPresent.clear();
         const EffectWindowList& originalwindowlist = effects->stackingOrder();
@@ -316,6 +310,13 @@ void PresentWindowsEffect::setActive(bool active)
                 continue;
             mWindowsToPresent.append(window);
             }
+        if( mWindowsToPresent.isEmpty())
+            {
+            mActivated = false; // don't activate with nothing to show
+            return;
+            }
+        mActiveness = 0;
+        effectActivated();
         rearrangeWindows();
         setHighlightedWindow( effects->activeWindow());
         }
@@ -1024,25 +1025,19 @@ void PresentWindowsEffect::paintWindowIcon( EffectWindow* w, WindowPaintData& pa
         }
 
     WindowData& data = mWindowData[ w ];
-    // TODO: find out why this doesn't work properly
-    // if( data.icon.cacheKey() != w->icon().cacheKey())
+    if( data.icon.cacheKey() != w->icon().cacheKey())
         { // make sure data.icon is the right QPixmap, and rebind
         data.icon = w->icon();
 #ifdef KWIN_HAVE_OPENGL_COMPOSITING
         if( effects->compositingType() == OpenGLCompositing )
             {
-            data.iconTexture.load( data.icon );
-            data.iconTexture.setFilter( GL_LINEAR );
+            data.iconTexture = new GLTexture( data.icon );
+            data.iconTexture->setFilter( GL_LINEAR );
             }
 #endif
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
         if( effects->compositingType() == XRenderCompositing )
-            {
-            if( data.iconPicture != None )
-                XRenderFreePicture( display(), data.iconPicture );
-            data.iconPicture = XRenderCreatePicture( display(),
-                data.icon.handle(), alphaFormat, 0, NULL );
-            }
+            data.iconPicture = XRenderPicture( data.icon );
 #endif
         }
     int icon_margin = 8;
@@ -1062,7 +1057,7 @@ void PresentWindowsEffect::paintWindowIcon( EffectWindow* w, WindowPaintData& pa
         // Render the icon
         glColor4f( 1, 1, 1, 1 * mActiveness );
         glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-        data.iconTexture.bind();
+        data.iconTexture->bind();
         const float verts[ 4 * 2 ] =
             {
             x, y,
@@ -1078,7 +1073,7 @@ void PresentWindowsEffect::paintWindowIcon( EffectWindow* w, WindowPaintData& pa
             1, 1
             };
         renderGLGeometry( 4, verts, texcoords );
-        data.iconTexture.unbind();
+        data.iconTexture->unbind();
         glPopAttrib();
         }
 #endif
