@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "presentwindows_config.h"
 
@@ -59,15 +69,15 @@ PresentWindowsEffectConfig::PresentWindowsEffectConfig(QWidget* parent, const QV
     KGlobalAccel::self()->overrideMainComponentData(componentData());
     KActionCollection* actionCollection = new KActionCollection( this );
     KAction* a = (KAction*)actionCollection->addAction( "Expose" );
-    a->setText( i18n("Toggle Expose effect" ));
-    a->setGlobalShortcut(KShortcut(Qt::CTRL + Qt::Key_F10));
+    a->setText( i18n("Toggle Expose Effect" ));
+    a->setGlobalShortcut(KShortcut(Qt::CTRL + Qt::Key_F9));
     KAction* b = (KAction*)actionCollection->addAction( "ExposeAll" );
     b->setText( i18n("Toggle Expose effect (incl other desktops)" ));
-    b->setGlobalShortcut(KShortcut(Qt::CTRL + Qt::Key_F11));
-    KShortcutsEditor* shortcutEditor = new KShortcutsEditor(actionCollection, this,
+    b->setGlobalShortcut(KShortcut(Qt::CTRL + Qt::Key_F10));
+    mShortcutEditor = new KShortcutsEditor(actionCollection, this,
             KShortcutsEditor::GlobalAction, KShortcutsEditor::LetterShortcutsDisallowed);
-    connect(shortcutEditor, SIGNAL(keyChange()), this, SLOT(changed()));
-    layout->addWidget(shortcutEditor, 4, 0, 1, 3);
+    connect(mShortcutEditor, SIGNAL(keyChange()), this, SLOT(changed()));
+    layout->addWidget(mShortcutEditor, 4, 0, 1, 3);
 
     layout->addItem(new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Expanding), 5, 0, 1, 3);
 
@@ -99,12 +109,12 @@ void PresentWindowsEffectConfig::load()
     KCModule::load();
 
     KConfigGroup conf = EffectsHandler::effectConfig("PresentWindows");
-    int activateBorder = conf.readEntry("BorderActivate", (int)ElectricTopRight);
+    int activateBorder = conf.readEntry("BorderActivate", (int)ElectricNone);
     if(activateBorder == (int)ElectricNone)
         activateBorder--;
     mActivateCombo->setCurrentIndex(activateBorder);
 
-    int activateAllBorder = conf.readEntry("BorderActivateAll", (int)ElectricNone);
+    int activateAllBorder = conf.readEntry("BorderActivateAll", (int)ElectricTopLeft);
     if(activateAllBorder == (int)ElectricNone)
         activateAllBorder--;
     mActivateAllCombo->setCurrentIndex(activateAllBorder);
@@ -138,8 +148,9 @@ void PresentWindowsEffectConfig::save()
 void PresentWindowsEffectConfig::defaults()
     {
     kDebug() ;
-    mActivateCombo->setCurrentIndex( (int)ElectricTopRight );
-    mActivateAllCombo->setCurrentIndex( (int)ElectricNone - 1 );
+    mActivateCombo->setCurrentIndex( (int)ElectricNone - 1 );
+    mActivateAllCombo->setCurrentIndex( (int)ElectricTopLeft );
+    mShortcutEditor->allDefault();
     emit changed(true);
     }
 
