@@ -1,12 +1,22 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 2007 Rivo Laks <rivolaks@hot.ee>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "advanced.h"
 #include "advanced.moc"
@@ -26,7 +36,7 @@ KWinAdvancedCompositingOptions::KWinAdvancedCompositingOptions(QWidget* parent,
     mKWinConfig = config;
     mDefaultPrefs = defaults;
 
-    setCaption(i18n("Advanced compositing options"));
+    setCaption(i18n("Advanced Compositing Options"));
     setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
     setModal(true);
 
@@ -37,6 +47,7 @@ KWinAdvancedCompositingOptions::KWinAdvancedCompositingOptions(QWidget* parent,
     connect(ui.compositingType, SIGNAL(currentIndexChanged(int)), this, SLOT(compositingModeChanged()));
 
     connect(ui.compositingType, SIGNAL(currentIndexChanged(int)), this, SLOT(changed()));
+    connect(ui.updateThumbnails, SIGNAL(toggled(bool)), this, SLOT(changed()));
     connect(ui.glMode, SIGNAL(currentIndexChanged(int)), this, SLOT(changed()));
     connect(ui.glTextureFilter, SIGNAL(currentIndexChanged(int)), this, SLOT(changed()));
     connect(ui.glDirect, SIGNAL(toggled(bool)), this, SLOT(changed()));
@@ -76,6 +87,8 @@ void KWinAdvancedCompositingOptions::showConfirmDialog()
         QMap<QString, QString>::const_iterator it = mPreviousConfig.constBegin();
         for(; it != mPreviousConfig.constEnd(); ++it)
         {
+            if (it.value().isEmpty())
+                continue;
             config.writeEntry(it.key(), it.value());
         }
         // Reinit KWin compositing and reload (old) settings
@@ -89,6 +102,7 @@ void KWinAdvancedCompositingOptions::load()
     KConfigGroup config(mKWinConfig, "Compositing");
     QString backend = config.readEntry("Backend", "OpenGL");
     ui.compositingType->setCurrentIndex((backend == "XRender") ? 1 : 0);
+    ui.updateThumbnails->setChecked(config.readEntry("HiddenPreviews", 0) == 3);
 
     QString glMode = config.readEntry("GLMode", "TFP");
     ui.glMode->setCurrentIndex((glMode == "TFP") ? 0 : ((glMode == "SHM") ? 1 : 2));
@@ -112,6 +126,7 @@ void KWinAdvancedCompositingOptions::save()
     mPreviousConfig = config.entryMap();
 
     config.writeEntry("Backend", (ui.compositingType->currentIndex() == 0) ? "OpenGL" : "XRender");
+    config.writeEntry("HiddenPreviews", ui.updateThumbnails->isChecked() ? 3 : 0);
     QString glModes[] = { "TFP", "SHM", "Fallback" };
 
     config.writeEntry("GLMode", glModes[ui.glMode->currentIndex()]);
