@@ -83,6 +83,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "group.h"
 #include "rules.h"
 #include "unmanaged.h"
+#include "deleted.h"
 #include <QX11Info>
 
 namespace KWin
@@ -289,7 +290,7 @@ void Workspace::raiseOrLowerClient( Client *c)
     }
 
 
-void Workspace::lowerClient( Client* c )
+void Workspace::lowerClient( Client* c, bool nogroup )
     {
     if ( !c )
         return;
@@ -302,14 +303,17 @@ void Workspace::lowerClient( Client* c )
 
     unconstrained_stacking_order.removeAll( c );
     unconstrained_stacking_order.prepend( c );
-    if( c->isTransient())
+    if( !nogroup && c->isTransient() )
         {
-        // lower also mainclients, in their reversed stacking order
-        ClientList mainclients = ensureStackingOrder( c->mainClients());
-        for( int i = mainclients.size() - 1;
+        // lower also all windows in the group, in their reversed stacking order
+        ClientList wins = ensureStackingOrder( c->group()->members());
+        for( int i = wins.size() - 1;
              i >= 0;
              --i )
-            lowerClient( mainclients[ i ] );
+            {
+            if( wins[ i ] != c )
+                lowerClient( wins[ i ], true );
+            }
         }
 
     if ( c == most_recently_raised )
@@ -344,7 +348,7 @@ void Workspace::lowerClientWithinApplication( Client* c )
     // ignore mainwindows
     }
 
-void Workspace::raiseClient( Client* c )
+void Workspace::raiseClient( Client* c, bool nogroup )
     {
     if ( !c )
         return;
@@ -355,13 +359,12 @@ void Workspace::raiseClient( Client* c )
 
     StackingUpdatesBlocker blocker( this );
 
-    if( c->isTransient())
+    if( !nogroup && c->isTransient())
         {
-        ClientList mainclients = ensureStackingOrder( c->mainClients());
-        for( ClientList::ConstIterator it = mainclients.begin();
-             it != mainclients.end();
-             ++it )
-            raiseClient( *it );
+        ClientList wins = ensureStackingOrder( c->group()->members());
+        foreach( Client* c2, wins )
+            if( c2 != c )
+                raiseClient( c2, true );
         }
 
     unconstrained_stacking_order.removeAll( c );
@@ -713,42 +716,29 @@ bool Workspace::keepTransientAbove( const Client* mainwindow, const Client* tran
     return true;
     }
 
-void Workspace::restackUnmanaged( Unmanaged* c, Window above )
+// Returns all windows in their stacking order on the root window, used only by compositing.
+// TODO This possibly should be optimized to avoid the X roundtrip and building it every pass.
+ToplevelList Workspace::rootStackingOrder() const
     {
-    if( above == None )
-        {
-        unmanaged_stacking_order.removeAll( c );
-        unmanaged_stacking_order.prepend( c );
-        addRepaint( c->geometry());
-        return;
-        }
-    bool was_below = false;
-    for( int i = 0;
-         i < unmanaged_stacking_order.size();
+    Window dummy;
+    Window* windows = NULL;
+    unsigned int count = 0;
+    XQueryTree( display(), rootWindow(), &dummy, &dummy, &windows, &count );
+    ToplevelList ret;
+    for( unsigned int i = 0;
+         i < count;
          ++i )
         {
-        if( unmanaged_stacking_order.at( i )->window() == above )
-            {
-            if( i + 1 < unmanaged_stacking_order.size()
-                && unmanaged_stacking_order.at( i ) == c )
-                {
-                // it is already there, do nothing
-                return;
-                }
-            unmanaged_stacking_order.removeAll( c );
-            if( was_below )
-                --i;
-            unmanaged_stacking_order.insert( i, c );
-            addRepaint( c->geometry());
-            return;
-            }
-        if( unmanaged_stacking_order.at( i ) == c )
-            was_below = true;
+        if( Client* c = findClient( FrameIdMatchPredicate( windows[ i ] )))
+            ret.append( c );
+        else if( Unmanaged* c = findUnmanaged( WindowMatchPredicate( windows[ i ] )))
+            ret.append( c );
         }
-    // TODO not found?
-    unmanaged_stacking_order.removeAll( c );
-    unmanaged_stacking_order.append( c );
-    addRepaint( c->geometry());
+    foreach( Deleted* c, deleted )
+        ret.append( c );
+    if( windows != NULL )
+        XFree( windows );
+    return ret;
     }
 
 //*******************************
