@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kwineffects.h"
 
 #include "kwinglutils.h"
+#include "kwinxrenderutils.h"
 
 #include <QtDBus/QtDBus>
 #include <QVariant>
@@ -288,6 +289,19 @@ CompositingType EffectsHandler::compositingType() const
     return compositing_type;
     }
 
+bool EffectsHandler::saturationSupported() const
+    {
+    switch( compositing_type )
+        {
+        case OpenGLCompositing:
+            return GLTexture::saturationSupported();
+        case XRenderCompositing:
+            return false; // never
+        default:
+            abort();
+        }
+    }
+
 void EffectsHandler::sendReloadMessage( const QString& effectname )
     {
     QDBusMessage message = QDBusMessage::createMethodCall("org.kde.kwin", "/KWin", "org.kde.KWin", "reloadEffect");
@@ -357,15 +371,10 @@ bool EffectsHandler::paintText( const QString& text, const QPoint& center, int m
 #ifdef KWIN_HAVE_XRENDER_COMPOSITING
     if( effects->compositingType() == XRenderCompositing )
         {
-        static XRenderPictFormat* alphaFormat = 0;
-        if( !alphaFormat)
-            alphaFormat = XRenderFindStandardFormat( display(), PictStandardARGB32 );
-        Picture textPicture;
-        textPicture = XRenderCreatePicture( display(), textPixmap.handle(), alphaFormat, 0, NULL );
+        XRenderPicture textPicture( textPixmap );
         XRenderComposite( display(), textPixmap.depth() == 32 ? PictOpOver : PictOpSrc,
-        textPicture, None, effects->xrenderBufferPicture(),
-        0, 0, 0, 0, area.x(), area.y(), area.width(), area.height());
-        XRenderFreePicture( display(), textPicture );
+            textPicture, None, effects->xrenderBufferPicture(),
+            0, 0, 0, 0, area.x(), area.y(), area.width(), area.height());
         return true;
         }
 #endif
