@@ -43,7 +43,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #define KWIN_EFFECT_API_MAKE_VERSION( major, minor ) (( major ) << 8 | ( minor )) 
 #define KWIN_EFFECT_API_VERSION_MAJOR 0
-#define KWIN_EFFECT_API_VERSION_MINOR 6
+#define KWIN_EFFECT_API_VERSION_MINOR 8
 #define KWIN_EFFECT_API_VERSION KWIN_EFFECT_API_MAKE_VERSION( \
     KWIN_EFFECT_API_VERSION_MAJOR, KWIN_EFFECT_API_VERSION_MINOR )
 
@@ -418,6 +418,7 @@ class KWIN_EXPORT EffectsHandler
 
         CompositingType compositingType() const;
         virtual unsigned long xrenderBufferPicture() = 0;
+        bool saturationSupported() const;
         virtual void reconfigure() = 0;
 
         /**
@@ -701,6 +702,8 @@ class KWIN_EXPORT WindowPaintData
          * 1 means that the window is unchanged, 0 means that it's completely
          *  unsaturated (greyscale). 0.5 would make the colors less intense,
          *  but not completely grey
+         * Use EffectsHandler::saturationSupported() to find out whether saturation
+         * is supported by the system, otherwise this value has no effect.
          **/
         double saturation;
         /**
