@@ -314,11 +314,13 @@ Scene::Window::Window( Toplevel * c )
     , filter( ImageFilterFast )
     , disable_painting( 0 )
     , shape_valid( false )
+    , cached_quad_list( NULL )
     {
     }
 
 Scene::Window::~Window()
     {
+    delete cached_quad_list;
     }
 
 void Scene::Window::discardShape()
@@ -326,6 +328,8 @@ void Scene::Window::discardShape()
     // it is created on-demand and cached, simply
     // reset the flag
     shape_valid = false;
+    delete cached_quad_list;
+    cached_quad_list = NULL;
     }
 
 // Find out the shape of the window using the XShape extension
@@ -351,7 +355,7 @@ QRegion Scene::Window::shape() const
                 XFree(rects);
                 }
             else
-                shape_region = QRegion( 0, 0, width(), height());
+                shape_region = QRegion();
             }
         else
             shape_region = QRegion( 0, 0, width(), height());
@@ -396,6 +400,8 @@ void Scene::Window::resetPaintingEnabled()
         {
         if( c->isMinimized() )
             disable_painting |= PAINT_DISABLED_BY_MINIMIZE;
+        if( c->isHiddenInternal())
+            disable_painting |= PAINT_DISABLED;
         }
     }
 
@@ -411,12 +417,19 @@ void Scene::Window::disablePainting( int reason )
 
 WindowQuadList Scene::Window::buildQuads() const
     {
+    if( cached_quad_list != NULL )
+        return *cached_quad_list;
+    WindowQuadList ret;
     if( toplevel->clientPos() == QPoint( 0, 0 ) && toplevel->clientSize() == toplevel->size())
-        return makeQuads( WindowQuadContents, shape()); // has no decoration
-    QRegion contents = shape() & QRect( toplevel->clientPos(), toplevel->clientSize());
-    QRegion decoration = shape() - contents;
-    WindowQuadList ret = makeQuads( WindowQuadContents, contents );
-    ret += makeQuads( WindowQuadDecoration, decoration );
+        ret = makeQuads( WindowQuadContents, shape()); // has no decoration
+    else
+        {
+        QRegion contents = shape() & QRect( toplevel->clientPos(), toplevel->clientSize());
+        QRegion decoration = shape() - contents;
+        ret = makeQuads( WindowQuadContents, contents );
+        ret += makeQuads( WindowQuadDecoration, decoration );
+        }
+    cached_quad_list = new WindowQuadList( ret );
     return ret;
     }
 
