@@ -647,6 +647,8 @@ void SceneOpenGL::waitSync()
 // actually paint to the screen (double-buffer swap or copy from pixmap buffer)
 void SceneOpenGL::flushBuffer( int mask, QRegion damage )
     {
+    if( wspace->overlayWindow()) // show the window only after the first pass, since
+        wspace->showOverlay();   // that pass may take long
     if( db )
         {
         if( mask & PAINT_SCREEN_REGION )
@@ -725,11 +727,16 @@ void SceneOpenGL::paintBackground( QRegion region )
     {
     if( region == infiniteRegion())
         {
+        glPushAttrib( GL_COLOR_BUFFER_BIT );
         glClearColor( 0, 0, 0, 1 ); // black
         glClear( GL_COLOR_BUFFER_BIT );
+        glPopAttrib();
         }
     else
         {
+        if( region.isEmpty())
+            return;
+        glPushAttrib( GL_CURRENT_BIT );
         glColor4f( 0, 0, 0, 1 ); // black
         glBegin( GL_QUADS );
         foreach( QRect r, region.rects())
@@ -740,6 +747,7 @@ void SceneOpenGL::paintBackground( QRegion region )
             glVertex2i( r.x(), r.y() + r.height());
             }
         glEnd();
+        glPopAttrib();
         }
     }
 
