@@ -45,6 +45,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "client.h"
 #include "deleted.h"
 #include "effects.h"
+#include "kwinxrenderutils.h"
 
 #include <kxerrorhandler.h>
 
@@ -96,17 +97,28 @@ SceneXrender::SceneXrender( Workspace* ws )
         return;
         }
     KXErrorHandler xerr;
-    // create XRender picture for the root window
-    format = XRenderFindVisualFormat( display(), DefaultVisual( display(), DefaultScreen( display())));
-    if( format == NULL )
-        return; // error
     if( wspace->createOverlay())
         {
         wspace->setupOverlay( None );
+        XWindowAttributes attrs;
+        XGetWindowAttributes( display(), wspace->overlayWindow(), &attrs );
+        format = XRenderFindVisualFormat( display(), attrs.visual );
+        if( format == NULL )
+            {
+            kError( 1212 ) << "Failed to find XRender format for overlay window";
+            return;
+            }
         front = XRenderCreatePicture( display(), wspace->overlayWindow(), format, 0, NULL );
         }
     else
         {
+        // create XRender picture for the root window
+        format = XRenderFindVisualFormat( display(), DefaultVisual( display(), DefaultScreen( display())));
+        if( format == NULL )
+            {
+            kError( 1212 ) << "Failed to find XRender format for root window";
+            return; // error
+            }
         XRenderPictureAttributes pa;
         pa.subwindow_mode = IncludeInferiors;
         front = XRenderCreatePicture( display(), rootWindow(), format, CPSubwindowMode, &pa );
@@ -158,6 +170,8 @@ void SceneXrender::paint( QRegion damage, ToplevelList toplevels )
         }
     int mask = 0;
     paintScreen( &mask, &damage );
+    if( wspace->overlayWindow()) // show the window only after the first pass, since
+        wspace->showOverlay();   // that pass may take long
     if( mask & PAINT_SCREEN_REGION )
         {
         // Use the damage region as the clip region for the root window
@@ -183,13 +197,14 @@ void SceneXrender::paint( QRegion damage, ToplevelList toplevels )
 void SceneXrender::paintGenericScreen( int mask, ScreenPaintData data )
     {
     screen_paint = data; // save, transformations will be done when painting windows
-    if( false ) // TODO never needed?
+    if( true ) // as long as paintTransformedScreen() doesn't work properly
         Scene::paintGenericScreen( mask, data );
     else
         paintTransformedScreen( mask );
     }
 
 /*
+ TODO currently broken
  Try to do optimized painting even with transformations. Since only scaling
  and translation are supported by the painting code, clipping can be done
  manually to avoid having to paint everything in every pass. Whole screen
@@ -451,12 +466,6 @@ void SceneXrender::Window::performPaint( int mask, QRegion region, WindowPaintDa
         if( opaque )
             return;
         }
-    if( region != infiniteRegion())
-        {
-        XserverRegion clip_region = toXserverRegion( region );
-        XFixesSetPictureClipRegion( display(), buffer, 0, 0, clip_region );
-        XFixesDestroyRegion( display(), clip_region );
-        }
     Picture pic = picture(); // get XRender picture
     if( pic == None ) // The render format can be null for GL and/or Xv visuals
         return;
@@ -520,18 +529,29 @@ void SceneXrender::Window::performPaint( int mask, QRegion region, WindowPaintDa
             }
         transformed_shape.setRects( rects.constData(), rects.count());
         }
-    if( x != toplevel->x() || y != toplevel->y())
-        transformed_shape.translate( x, y );
+    transformed_shape.translate( x, y );
+    QRegion clipregion = transformed_shape;
+    if( region != infiniteRegion())
+        clipregion &= region;
+    XserverRegion clip = toXserverRegion( clipregion );
+    XFixesSetPictureClipRegion( display(), buffer, 0, 0, clip );
+    XFixesDestroyRegion( display(), clip );
     if( opaque )
         {
         XRenderComposite( display(), PictOpSrc, pic, None, buffer, 0, 0, 0, 0,
             x, y, width, height);
+        // fake brightness change by overlaying black
+        XRenderColor col = { 0, 0, 0, 0xffff * ( 1 - data.brightness ) };
+        XRenderFillRectangle( display(), PictOpOver, buffer, &col, x, y, width, height );
         }
     else
         {
         Picture alpha = alphaMask( data.opacity );
         XRenderComposite( display(), PictOpOver, pic, alpha, buffer, 0, 0, 0, 0,
             x, y, width, height);
+        // fake brightness change by overlaying black
+        XRenderColor col = { 0, 0, 0, 0xffff * ( 1 - data.brightness ) * data.opacity };
+        XRenderFillRectangle( display(), PictOpOver, buffer, &col, x, y, width, height );
         transformed_shape = QRegion();
         }
     if( xscale != 1 || yscale != 1 )
