@@ -1,13 +1,23 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #include "sm.h"
 
@@ -205,45 +215,54 @@ SessionInfo* Workspace::takeSessionInfo( Client* c )
     // First search ``session''
     if (! sessionId.isEmpty() ) 
         {
-			// look for a real session managed client (algorithm suggested by ICCCM)
-			foreach( SessionInfo* info, session ) {
-				if ( realInfo )
-					break;
-				if ( info->sessionId == sessionId && sessionInfoWindowTypeMatch( c, info )) 
-				{
-				if ( ! windowRole.isEmpty() ) 
-					{
-					if ( info->windowRole == windowRole )
-						realInfo = info;
-						session.removeAll(info);
-					}
-				else 
-					{
-					if ( info->windowRole.isEmpty() &&
-						 info->resourceName == resourceName &&
-						 info->resourceClass == resourceClass )
-						realInfo = info;
-						session.removeAll(info);
-					}
-				}
-			}
+        // look for a real session managed client (algorithm suggested by ICCCM)
+        foreach( SessionInfo* info, session )
+            {
+            if( realInfo )
+                break;
+            if( info->sessionId == sessionId && sessionInfoWindowTypeMatch( c, info )) 
+                {
+                if( ! windowRole.isEmpty() ) 
+                    {
+                    if( info->windowRole == windowRole )
+                        {
+                        realInfo = info;
+                        session.removeAll(info);
+                        }
+                    }
+                else 
+                    {
+                    if( info->windowRole.isEmpty()
+                        && info->resourceName == resourceName
+                        && info->resourceClass == resourceClass )
+                        {
+                        realInfo = info;
+                        session.removeAll(info);
+                        }
+                    }
+                }
+            }
         }
     else 
         {
-			// look for a sessioninfo with matching features.
-			foreach( SessionInfo* info, session ) {
-				if ( realInfo ) break;
-				if ( info->resourceName == resourceName &&
-						info->resourceClass == resourceClass &&
-						info->wmClientMachine == wmClientMachine &&
-						sessionInfoWindowTypeMatch( c, info ))
-					if ( wmCommand.isEmpty() || info->wmCommand == wmCommand ) {
-						realInfo = info;
-						session.removeAll( info );
-					}
-			}
+        // look for a sessioninfo with matching features.
+        foreach( SessionInfo* info, session )
+            {
+            if( realInfo )
+                break;
+            if( info->resourceName == resourceName
+                && info->resourceClass == resourceClass
+                && info->wmClientMachine == wmClientMachine
+                && sessionInfoWindowTypeMatch( c, info ))
+                {
+                if ( wmCommand.isEmpty() || info->wmCommand == wmCommand )
+                    {
+                    realInfo = info;
+                    session.removeAll( info );
+                    }
+                }
+            }
         }
-
     return realInfo;
     }
 
@@ -386,8 +405,8 @@ SessionSaveDoneHelper::SessionSaveDoneHelper()
     props[ 2 ].type = const_cast< char* >( SmLISTofARRAY8 );
     props[ 2 ].num_vals = 1;
     props[ 2 ].vals = &propvalue[ 2 ];
-    propvalue[ 3 ].length = 0;
-    propvalue[ 3 ].value = qApp->argv()[ 0 ];
+    propvalue[ 3 ].length = strlen( "kwinsmhelper" );
+    propvalue[ 3 ].value = (SmPointer)"kwinsmhelper";
     props[ 3 ].name = const_cast< char* >( SmProgram );
     props[ 3 ].type = const_cast< char* >( SmARRAY8 );
     props[ 3 ].num_vals = 1;
