@@ -1,13 +1,23 @@
-/*****************************************************************
+/********************************************************************
  KWin - the KDE window manager
  This file is part of the KDE project.
 
 Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
 
-You can Freely distribute this program under the GNU General Public
-License. See the file "COPYING" for the exact licensing terms.
-******************************************************************/
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
 
 #ifndef KWIN_UTILS_H
 #define KWIN_UTILS_H
@@ -16,6 +26,8 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <config-X11.h>
 #include <config-kwin.h>
 
+#include <kwinconfig.h>
+
 #include <X11/Xlib.h>
 
 #include <fixx11h.h>
@@ -23,9 +35,10 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <QWidget>
 #include <kmanagerselection.h>
 #include <netwm_def.h>
-//#include <kshortcutdialog.h> //you really want to use KKeySequenceWidget
+#include <kkeysequencewidget.h>
 #include <limits.h>
 #include <QX11Info>
+#include <kdialog.h>
 
 #include <kwinglobals.h>
 
@@ -40,7 +53,12 @@ struct XDamageNotifyEvent
     };
 #endif
 
-const int SUPPORTED_WINDOW_TYPES_MASK = NET::NormalMask | NET::DesktopMask | NET::DockMask
+// window types that are supported as normal windows (i.e. KWin actually manages them)
+const int SUPPORTED_MANAGED_WINDOW_TYPES_MASK = NET::NormalMask | NET::DesktopMask | NET::DockMask
+    | NET::ToolbarMask | NET::MenuMask | NET::DialogMask /*| NET::OverrideMask*/ | NET::TopMenuMask
+    | NET::UtilityMask | NET::SplashMask;
+// window types that are supported as unmanaged (mainly for compositing)
+const int SUPPORTED_UNMANAGED_WINDOW_TYPES_MASK = NET::NormalMask | NET::DesktopMask | NET::DockMask
     | NET::ToolbarMask | NET::MenuMask | NET::DialogMask /*| NET::OverrideMask*/ | NET::TopMenuMask
     | NET::UtilityMask | NET::SplashMask | NET::DropdownMenuMask | NET::PopupMenuMask
     | NET::TooltipMask | NET::NotificationMask | NET::ComboBoxMask | NET::DNDIconMask;
@@ -291,24 +309,22 @@ void checkNonExistentClients();
 
 #ifndef KCMRULES
 // Qt dialogs emit no signal when closed :(
-
-// KShortcutDialog is gone, and K(Shortcut/KeySequence)Widget should replace it and be
-// good enough to not need any further hacks here. If they aren't, CONTACT ME before
-// you add hacks again. --ahartmetz
-#if 0
 class ShortcutDialog
-    : public KShortcutDialog
+    : public KDialog
     {
     Q_OBJECT
     public:
-        ShortcutDialog( const KShortcut& cut );
+        ShortcutDialog( const QKeySequence& cut );
         virtual void accept();
+        QKeySequence shortcut() const;
     signals:
         void dialogDone( bool ok );
     protected:
-        virtual void done( int r ) { KShortcutDialog::done( r ); emit dialogDone( r == Accepted ); }
+        virtual void done( int r );
+    private:
+        KKeySequenceWidget* widget;
     };
-#endif //0
+
 #endif //KCMRULES
 
 } // namespace
