@@ -124,8 +124,6 @@ Workspace::Workspace( bool restore )
     layoutOrientation(Qt::Vertical),
     layoutX(-1),
     layoutY(2),
-    workarea(NULL),
-    screenarea(NULL),
     managing_topmenus( false ),
     topmenu_selection( NULL ),
     topmenu_watcher( NULL ),
@@ -138,6 +136,7 @@ Workspace::Workspace( bool restore )
     compositeRate( 0 ),
     overlay( None ),
     overlay_visible( true ),
+    overlay_shown( false ),
     transSlider( NULL ),
     transButton( NULL )
     {
@@ -467,8 +466,6 @@ Workspace::~Workspace()
     delete rootInfo;
     delete supportWindow;
     delete mgr;
-    delete[] workarea;
-    delete[] screenarea;
     delete startup;
     delete initPositioning;
     delete topmenu_watcher;
@@ -567,7 +564,6 @@ void Workspace::addClient( Client* c, allowed_t )
 void Workspace::addUnmanaged( Unmanaged* c, allowed_t )
     {
     unmanaged.append( c );
-    unmanaged_stacking_order.append( c );
     }
 
 /*
@@ -635,7 +631,6 @@ void Workspace::removeUnmanaged( Unmanaged* c, allowed_t )
     {
     assert( unmanaged.contains( c ));
     unmanaged.removeAll( c );
-    unmanaged_stacking_order.removeAll( c );
     }
 
 void Workspace::addDeleted( Deleted* c, allowed_t )
@@ -1085,10 +1080,9 @@ void Workspace::loadDesktopSettings()
 
     int n = group.readEntry("Number", 4);
     number_of_desktops = n;
-    delete workarea;
-    workarea = new QRect[ n + 1 ];
-    delete screenarea;
-    screenarea = NULL;
+    workarea.clear();
+    workarea.resize( n + 1 );
+    screenarea.clear();
     rootInfo->setNumberOfDesktops( number_of_desktops );
     desktop_focus_chain.resize( n );
     // make it +1, so that it can be accessed as [1..numberofdesktops]
