@@ -74,10 +74,10 @@ class Workspace : public QObject, public KDecorationDefines
 
         bool hasClient( const Client * );
 
-        template< typename T > Client* findClient( T predicate );
+        template< typename T > Client* findClient( T predicate ) const;
         template< typename T1, typename T2 > void forEachClient( T1 procedure, T2 predicate );
         template< typename T > void forEachClient( T procedure );
-        template< typename T > Unmanaged* findUnmanaged( T predicate );
+        template< typename T > Unmanaged* findUnmanaged( T predicate ) const;
         template< typename T1, typename T2 > void forEachUnmanaged( T1 procedure, T2 predicate );
         template< typename T > void forEachUnmanaged( T procedure );
 
@@ -129,15 +129,14 @@ class Workspace : public QObject, public KDecorationDefines
 
         QPoint adjustClientPosition( Client* c, QPoint pos );
         QRect adjustClientSize( Client* c, QRect moveResizeGeom, int mode );
-        void raiseClient( Client* c );
-        void lowerClient( Client* c );
+        void raiseClient( Client* c, bool nogroup = false );
+        void lowerClient( Client* c, bool nogroup = false );
         void raiseClientRequest( Client* c, NET::RequestSource src, Time timestamp );
         void lowerClientRequest( Client* c, NET::RequestSource src, Time timestamp );
         void restackClientUnderActive( Client* );
         void updateClientLayer( Client* c );
         void raiseOrLowerClient( Client * );
         void restoreSessionStackingOrder( Client* c );
-        void restackUnmanaged( Unmanaged* c, Window above );
         void reconfigure();
         void forceRestacking();
 
@@ -318,6 +317,7 @@ class Workspace : public QObject, public KDecorationDefines
         bool createOverlay();
         // init overlay and the destination window in it
         void setupOverlay( Window window );
+        void showOverlay();
         // destroys XComposite overlay window
         void destroyOverlay();
         Window overlayWindow();
@@ -507,6 +507,7 @@ class Workspace : public QObject, public KDecorationDefines
         void removeTabBoxGrab();
 
         void updateStackingOrder( bool propagate_new_clients = false );
+        ToplevelList rootStackingOrder() const;
         void propagateClients( bool propagate_new_clients ); // called only from updateStackingOrder
         ClientList constrainedStackingOrder();
         void raiseClientWithinApplication( Client* c );
@@ -600,7 +601,6 @@ class Workspace : public QObject, public KDecorationDefines
 
         ClientList unconstrained_stacking_order; // topmost last
         ClientList stacking_order; // topmost last
-        UnmanagedList unmanaged_stacking_order;
         bool force_restacking;
         QVector< ClientList > focus_chain; // currently ative last
         ClientList global_focus_chain; // this one is only for things like tabbox's MRU
@@ -699,8 +699,8 @@ class Workspace : public QObject, public KDecorationDefines
 
         Placement *initPositioning;
 
-        QRect* workarea; //  array of workareas for virtual desktops
-        QRect** screenarea; // array of workareas per xinerama screen for all virtual desktops
+        QVector< QRect > workarea; //  array of workareas for virtual desktops
+        QVector< QVector< QRect > > screenarea; // array of workareas per xinerama screen for all virtual desktops
 
         bool managing_topmenus;
         KSelectionOwner* topmenu_selection;
@@ -723,6 +723,7 @@ class Workspace : public QObject, public KDecorationDefines
         QRegion repaints_region;
         Window overlay; // XComposite overlay window
         bool overlay_visible;
+        bool overlay_shown; // for showOverlay()
         QSlider *transSlider;
         QPushButton *transButton;
 
@@ -895,7 +896,7 @@ QPoint Workspace::focusMousePosition() const
     }
 
 template< typename T >
-inline Client* Workspace::findClient( T predicate )
+inline Client* Workspace::findClient( T predicate ) const
     {
     if( Client* ret = findClientInList( clients, predicate ))
         return ret;
@@ -922,7 +923,7 @@ inline void Workspace::forEachClient( T procedure )
     }
 
 template< typename T >
-inline Unmanaged* Workspace::findUnmanaged( T predicate )
+inline Unmanaged* Workspace::findUnmanaged( T predicate ) const
     {
     return findUnmanagedInList( unmanaged, predicate );
     }
