@@ -19,16 +19,20 @@
 
 #include "applethandle_p.h"
 
+#include <QApplication>
 #include <QtGui/QGraphicsSceneMouseEvent>
 #include <QtGui/QLinearGradient>
 #include <QtGui/QPainter>
+#include <QtGui/QApplication>
 
 #include <KColorScheme>
+#include <KGlobalSettings>
 #include <KIcon>
 
 #include <cmath>
 #include <math.h>
 
+#include "plasma/view.h"
 #include "applet.h"
 #include "containment.h"
 #include "corona.h"
@@ -43,7 +47,6 @@ qreal _k_angleForPoints(const QPointF &center, const QPointF &pt1, const QPointF
 AppletHandle::AppletHandle(Containment *parent, Applet *applet)
     : QObject(),
       QGraphicsItem(parent),
-      m_buttonsOnRight(false),
       m_pressedButton(NoButton),
       m_containment(parent),
       m_applet(applet),
@@ -51,7 +54,11 @@ AppletHandle::AppletHandle(Containment *parent, Applet *applet)
       m_anim(FadeIn),
       m_animId(0),
       m_angle(0.0),
-      m_scale(1.0)
+      m_tempAngle(0.0),
+      m_scaleWidth(1.0),
+      m_scaleHeight(1.0),
+      m_buttonsOnRight(false),
+      m_pendingFade(false)
 {
     KColorScheme colors(QPalette::Active, KColorScheme::View, Theme::self()->colors());
     m_gradientColor = colors.background(KColorScheme::NormalBackground).color();
@@ -64,31 +71,54 @@ AppletHandle::AppletHandle(Containment *parent, Applet *applet)
     qreal cosine = originalMatrix.m11();
     qreal sine = originalMatrix.m12();
 
-    m_originalAngle = _k_angleForPoints(QPointF(0, 0),
-                                        QPointF(1, 0),
-                                        QPointF(cosine, sine));
+    m_angle = _k_angleForPoints(QPointF(0, 0),
+                                QPointF(1, 0),
+                                QPointF(cosine, sine));
+
+    m_applet->resetTransform();
 
     calculateSize();
     m_applet->setParentItem(this);
+
+    rect = QRectF(m_applet->pos(), m_applet->size());
+    center = rect.center();
+    QTransform matrix;
+    matrix.translate(center.x(), center.y());
+    matrix.rotateRadians(m_angle);
+    matrix.translate(-center.x(), -center.y());
+    setTransform(matrix);
+
+    m_hoverTimer = new QTimer(this);
+    m_hoverTimer->setSingleShot(true);
+    m_hoverTimer->setInterval(300);
+
+    connect(m_hoverTimer, SIGNAL(timeout()), this, SLOT(fadeIn()));
     connect(m_applet, SIGNAL(destroyed(QObject*)), this, SLOT(appletDestroyed()));
+
     setAcceptsHoverEvents(true);
-    startFading(FadeIn);
+    m_hoverTimer->start();
 }
 
 AppletHandle::~AppletHandle()
 {
     if (m_applet) {
-        QRectF rect(m_applet->boundingRect());
-        QPointF center = rect.center();
+        m_applet->removeSceneEventFilter(this);
+
+        QRectF rect = QRectF(m_applet->pos(), m_applet->size());
+        QPointF center = m_applet->mapFromParent(rect.center());
 
         QPointF newPos = transform().inverted().map(m_applet->pos());
         m_applet->setPos(mapToParent(newPos));
+
         QTransform matrix;
         matrix.translate(center.x(), center.y());
-        matrix.rotateRadians(m_originalAngle+m_angle);
+        matrix.rotateRadians(m_angle);
         matrix.translate(-center.x(), -center.y());
         m_applet->setTransform(matrix);
+
         m_applet->setParentItem(m_containment);
+
+        m_applet->update();
     }
 }
 
@@ -133,6 +163,7 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     QPointF shiftC;
     QPointF shiftD;
     QPointF shiftR;
+    QPointF shiftM;
 
     switch(m_pressedButton)
     {
@@ -145,16 +176,23 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     case RotateButton:
         shiftR = QPointF(2, 2);
         break;
+    case ResizeButton:
+        shiftM = QPointF(2, 2);
+        break;
     default:
         break;
     }
 
-    if (m_applet && m_applet->hasConfigurationInterface()) {
-        painter->drawPixmap(point + shiftC, KIcon("configure").pixmap(ICON_SIZE, ICON_SIZE));
-        point += QPointF(0.0, ICON_SIZE + ICON_MARGIN);
-    }
+    painter->drawPixmap(point + shiftM, KIcon("transform-move").pixmap(ICON_SIZE, ICON_SIZE)); // no transform-resize icon
+
+    point += QPointF(0.0, ICON_SIZE + ICON_MARGIN);
     painter->drawPixmap(point + shiftR, KIcon("transform-rotate").pixmap(ICON_SIZE, ICON_SIZE));
 
+    if (m_applet && m_applet->hasConfigurationInterface()) {
+        point += QPointF(0.0, ICON_SIZE + ICON_MARGIN);
+        painter->drawPixmap(point + shiftC, KIcon("configure").pixmap(ICON_SIZE, ICON_SIZE));
+    }
+
     point += QPointF(0.0, ICON_SIZE + ICON_MARGIN * 2);
     painter->drawPixmap(point + shiftD, KIcon("edit-delete").pixmap(ICON_SIZE, ICON_SIZE));
 
@@ -173,15 +211,20 @@ AppletHandle::ButtonType AppletHandle::mapToButton(const QPointF &point) const
 
     QPolygonF activeArea = QPolygonF(QRectF(basePoint, QSizeF(ICON_SIZE, ICON_SIZE)));
 
+    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+        return ResizeButton;
+    }
+
+    activeArea.translate(QPointF(0.0, ICON_SIZE + ICON_MARGIN));
+    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+        return RotateButton;
+    }
+
     if (m_applet && m_applet->hasConfigurationInterface()) {
+        activeArea.translate(QPointF(0.0, ICON_SIZE + ICON_MARGIN));
         if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
             return ConfigureButton;
         }
-        activeArea.translate(QPointF(0.0, ICON_SIZE + ICON_MARGIN));
-    }
-
-    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
-        return RotateButton;
     }
 
     activeArea.translate(QPointF(0.0, ICON_SIZE + ICON_MARGIN * 2));
@@ -195,8 +238,17 @@ AppletHandle::ButtonType AppletHandle::mapToButton(const QPointF &point) const
 
 void AppletHandle::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
+    if (m_pendingFade) {
+        //m_pendingFade = false;
+        return;
+    }
+
     if (event->button() == Qt::LeftButton) {
         m_pressedButton = mapToButton(event->pos());
+        //kDebug() << "button pressed:" << m_pressedButton;
+        if (m_pressedButton != NoButton) {
+            m_applet->installSceneEventFilter(this);
+        }
         event->accept();
         update();
         return;
@@ -207,28 +259,42 @@ void AppletHandle::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
 void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
+    //kDebug() << "button pressed:" << m_pressedButton << ", fade pending?" << m_pendingFade;
+    if (m_applet) {
+        m_applet->removeSceneEventFilter(this);
+    }
+
+    if (m_pendingFade) {
+        startFading(FadeOut);
+        m_pendingFade = false;
+        return;
+    }
+
     ButtonType releasedAtButton = mapToButton(event->pos());
 
     if (m_applet && event->button() == Qt::LeftButton) {
         switch (m_pressedButton) {
+            case ResizeButton:
             case RotateButton: {
-                if (m_scale > 0) {
+                if (m_scaleWidth > 0 && m_scaleHeight > 0) {
                     QRectF rect(m_applet->boundingRect());
-                    const qreal newWidth = rect.width() * m_scale;
-                    const qreal newHeight = rect.height() * m_scale;
+                    const qreal newWidth = rect.width() * m_scaleWidth;
+                    const qreal newHeight = rect.height() * m_scaleHeight;
                     m_applet->resetTransform();
                     m_applet->resize(newWidth, newHeight);
-                    scale(1.0/m_scale, 1.0/m_scale);
+                    scale(1.0/m_scaleWidth, 1.0/m_scaleHeight);
                     moveBy((rect.width() - newWidth) / 2, (rect.height() - newHeight) / 2);
-                    m_scale = 0;
+                    m_scaleWidth = m_scaleHeight = 0;
                 }
-
-                QRectF rect(boundingRect());
+                QRectF rect = QRectF(m_applet->pos(), m_applet->size());
                 QPointF center = rect.center();
 
+                m_angle += m_tempAngle;
+                m_tempAngle = 0;
+
                 QTransform matrix;
                 matrix.translate(center.x(), center.y());
-                matrix.rotateRadians(m_originalAngle+m_angle);
+                matrix.rotateRadians(m_angle);
                 matrix.translate(-center.x(), -center.y());
 
                 setTransform(matrix);
@@ -248,6 +314,27 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
                     Phase::self()->animateItem(m_applet, Phase::Disappear);
                 }
                 break;
+            case MoveButton: {
+                //find out if we were dropped on a panel or something
+                QWidget *w = QApplication::topLevelAt(event->screenPos());
+                kDebug() << "move to widget" << w;
+                if (w) {
+                    Plasma::View *v = qobject_cast<Plasma::View *>(w);
+                    if (v) {
+                        Containment *c = v->containment();
+                        //XXX the dashboard view won't give us a containment. if it did, this could
+                        //break shit.
+                        if (c && c != m_containment) {
+                            //we actually have been dropped on another containment, so move there
+                            //we have a screenpos, we need a scenepos
+                            //FIXME how reliable is this transform?
+                            QPoint pos = v->mapFromGlobal(event->screenPos());
+                            switchContainment(c, v->mapToScene(pos));
+                        }
+                    }
+                }
+                break;
+            }
             default:
                 break;
         }
@@ -298,23 +385,16 @@ void AppletHandle::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
                     if (containments[i]->sceneBoundingRect().contains(event->scenePos())) {
                         // add the applet to the new containment
                         // and take it from the old one
-                        QPointF scenePosition = scenePos();
-                        kDebug() << "moving to other containment with position" << pos() << event->scenePos();
-                        kDebug() << "position before reparenting" << pos() << scenePos();
-                        m_containment = containments[i];
-                        //m_containment->addChild(m_applet);
-                        //setParentItem(containments[i]);
-                        m_containment->addApplet(m_applet);
-                        setParentItem(m_containment);
-                        m_applet->setParentItem(this);
-                        setPos(m_containment->mapFromScene(scenePosition));
-                        update();
+                        //kDebug() << "moving to other containment with position" << pos() << event->scenePos();
+                        //kDebug() << "position before reparenting" << pos() << scenePos();
+                        switchContainment(containments[i], scenePos());
                         break;
                     }
                 }
             }
         }
-    } else if (m_pressedButton == RotateButton) {
+    } else if (m_pressedButton == RotateButton ||
+               m_pressedButton == ResizeButton) {
         if (_k_distanceForPoint(delta) <= 1.0) {
             return;
         }
@@ -324,44 +404,81 @@ void AppletHandle::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
         QRectF rect = QRectF(m_applet->pos(), m_applet->size());
         QPointF center = rect.center();
 
-        m_angle = _k_angleForPoints(center, pressPos, event->pos());
+        if (m_pressedButton == RotateButton) {
+            m_tempAngle = _k_angleForPoints(center, pressPos, event->pos());
 
-        if (fabs(remainder(m_originalAngle+m_angle, snapAngle)) < 0.15) {
-            m_angle = m_angle - remainder(m_originalAngle+m_angle, snapAngle);
-        }
+            if (fabs(remainder(m_angle+m_tempAngle, snapAngle)) < 0.15) {
+                m_tempAngle = m_tempAngle - remainder(m_angle+m_tempAngle, snapAngle);
+            }
 
-        qreal newScale = _k_distanceForPoint(event->pos()-center) / _k_distanceForPoint(pressPos-center);
-        if (qAbs(newScale-1.0)<=0.1) {
-            newScale = 1.0;
-        }
-
-        qreal w = m_applet->size().width();
-        qreal h = m_applet->size().height();
-        QSizeF min = m_applet->minimumSize();
-        QSizeF max = m_applet->maximumSize();
-
-        // If the applet doesn't have a minimum size, calculate based on a
-        // minimum content area size of 16x16
-        if (min.isEmpty()) {
-            min = m_applet->boundingRect().size() - m_applet->contentRect().size();
-            min += QSizeF(16, 16);
-        }
-
-        //FIXME: this code will only work if we are keeping the aspect ratio, as we currently do
-        //       as it resets only on the width, which will break if we allow resizing of width
-        //       and height independantly
-        if (newScale * w < min.width() || newScale * h < min.height()) {
-            m_scale = min.width() / w;
-        } else if (newScale * w > max.width() && newScale * h > max.height()) {
-            m_scale = max.width() / w;
+            m_scaleWidth = m_scaleHeight = 1.0;
         } else {
-            m_scale = newScale;
+            qreal w = m_applet->size().width();
+            qreal h = m_applet->size().height();
+            QSizeF min = m_applet->minimumSize();
+            QSizeF max = m_applet->maximumSize();
+
+            // If the applet doesn't have a minimum size, calculate based on a
+            // minimum content area size of 16x16
+            if (min.isEmpty()) {
+                min = m_applet->boundingRect().size() - m_applet->contentRect().size();
+                min += QSizeF(16, 16);
+            }
+
+            if (QApplication::keyboardModifiers() & Qt::ControlModifier) {
+                // free resizing
+                qreal newScaleWidth = 0;
+                qreal newScaleHeight = 0;
+
+                QPointF startDistance(pressPos - center);
+                QPointF currentDistance(event->pos() - center);
+                newScaleWidth = currentDistance.x() / startDistance.x();
+                newScaleHeight = currentDistance.y() / startDistance.y();
+
+                if (qAbs(w - (newScaleWidth * w)) <= KGlobalSettings::dndEventDelay()) {
+                    newScaleWidth = 1.0;
+                }
+                if (qAbs(h - (newScaleHeight * h)) <= KGlobalSettings::dndEventDelay()) {
+                    newScaleHeight = 1.0;
+                }
+
+                if (newScaleHeight * h < min.height()) {
+                    m_scaleHeight = min.height() / h;
+                } else if (newScaleHeight * h > max.height()) {
+                    m_scaleHeight = max.height() / h;
+                } else {
+                    m_scaleHeight = newScaleHeight;
+                }
+                if (newScaleWidth * w < min.width()) {
+                    m_scaleWidth = min.width() / w;
+                } else if (newScaleWidth * w > max.width()) {
+                    m_scaleWidth = max.width() / w;
+                } else {
+                    m_scaleWidth = newScaleWidth;
+                }
+            } else {
+                // maintain aspect ratio
+                qreal newScale = 0;
+
+                newScale = _k_distanceForPoint(event->pos()-center) / _k_distanceForPoint(pressPos-center);
+                if (qAbs(h - (newScale * h)) <= KGlobalSettings::dndEventDelay()) {
+                    newScale = 1.0;
+                }
+
+                if (newScale * w < min.width() || newScale * h < min.height()) {
+                    m_scaleWidth = m_scaleHeight = qMax(min.width() / w, min.height() / h);
+                } else if (newScale * w > max.width() && newScale * h > max.height()) {
+                    m_scaleWidth = m_scaleHeight = qMin(max.width() / w, max.height() / h);
+                } else {
+                    m_scaleHeight = m_scaleWidth = newScale;
+                }
+            }
         }
 
         QTransform matrix;
         matrix.translate(center.x(), center.y());
-        matrix.rotateRadians(m_angle);
-        matrix.scale(m_scale, m_scale);
+        matrix.rotateRadians(m_angle+m_tempAngle);
+        matrix.scale(m_scaleWidth, m_scaleHeight);
         matrix.translate(-center.x(), -center.y());
         setTransform(matrix);
     } else {
@@ -369,6 +486,31 @@ void AppletHandle::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
     }
 }
 
+//pos relative to scene
+void AppletHandle::switchContainment(Containment *containment, const QPointF &pos)
+{
+    Applet *applet=m_applet;
+    switch (containment->containmentType()) {
+        case Containment::PanelContainment:
+            kDebug() << "panel";
+            //we need to fully disassociate the applet and handle, then kill the handle
+            forceDisappear(); //takes care of event filter and killing handle
+            m_applet=0; //make sure we don't try to act on the applet again
+            applet->disconnect(this); //make sure the applet doesn't tell us to do anything
+            containment->addApplet(applet, containment->mapFromScene(pos));
+            break;
+        default: //FIXME assuming everything else behaves like desktop
+            kDebug() << "desktop";
+            m_containment = containment;
+            containment->addApplet(m_applet);
+            setParentItem(containment);
+            m_applet->setParentItem(this);
+            setPos(containment->mapFromScene(pos));
+            //setPos(pos);
+    }
+    update();
+}
+
 QVariant AppletHandle::itemChange(GraphicsItemChange change, const QVariant &value)
 {
     if (change == ItemPositionHasChanged && m_applet) {
@@ -381,14 +523,30 @@ void AppletHandle::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
     Q_UNUSED(event);
     //kDebug() << "hover enter";
-    startFading(FadeIn);
+    m_hoverTimer->start();
 }
 
 void AppletHandle::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
     Q_UNUSED(event);
-    //kDebug() << "hover leave";
-    startFading(FadeOut);
+    //kDebug() << "hover leave" << m_pressedButton;
+    m_hoverTimer->stop();
+
+    if (m_pressedButton != NoButton) {
+        m_pendingFade = true;
+    } else {
+        startFading(FadeOut);
+    }
+}
+
+bool AppletHandle::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
+{
+    if (watched == m_applet && event->type() == QEvent::GraphicsSceneHoverLeave) {
+        hoverLeaveEvent(static_cast<QGraphicsSceneHoverEvent*>(event));
+        return true;
+    }
+
+    return false;
 }
 
 void AppletHandle::fadeAnimation(qreal progress)
@@ -407,6 +565,11 @@ void AppletHandle::fadeAnimation(qreal progress)
     update();
 }
 
+void AppletHandle::fadeIn()
+{
+    startFading(FadeIn);
+}
+
 void AppletHandle::appletDestroyed()
 {
     m_applet = 0;
@@ -422,15 +585,21 @@ void AppletHandle::appletResized()
 
 void AppletHandle::startFading(FadeType anim)
 {
-    if (m_animId!=0) {
+    if (m_animId != 0) {
         Phase::self()->stopCustomAnimation(m_animId);
     }
 
     qreal time = 250;
+    m_hoverTimer->stop();
 
-    if (anim==FadeIn) {
+    if (m_applet) {
+        m_applet->removeSceneEventFilter(this);
+    }
+
+    if (anim == FadeIn) {
         time *= 1.0-m_opacity;
     } else {
+        m_hoverTimer->stop();
         time *= m_opacity;
     }
 
