@@ -87,7 +87,8 @@ class DataEngine::Private
             return s;
         }
 
-        void connectSource(DataContainer* s, QObject* visualization, uint updateInterval, Plasma::IntervalAlignment align)
+        void connectSource(DataContainer* s, QObject* visualization, uint updateInterval,
+                           Plasma::IntervalAlignment align, bool immediateCall = true)
         {
             //kDebug() << "connect source called with interval" << updateInterval;
             if (updateInterval > 0) {
@@ -101,13 +102,19 @@ class DataEngine::Private
 
             s->connectVisualization(visualization, updateInterval, align);
 
-            QMetaObject::invokeMethod(visualization, "updated",
-                                      Q_ARG(QString, s->objectName()),
-                                      Q_ARG(Plasma::DataEngine::Data, s->data()));
+            if (immediateCall) {
+                QMetaObject::invokeMethod(visualization, "dataUpdated",
+                                          Q_ARG(QString, s->objectName()),
+                                          Q_ARG(Plasma::DataEngine::Data, s->data()));
+            }
         }
 
-        DataContainer* requestSource(const QString& sourceName)
+        DataContainer* requestSource(const QString& sourceName, bool* newSource = 0)
         {
+            if (newSource) {
+                *newSource = false;
+            }
+
             //kDebug() << "requesting source " << sourceName;
             DataContainer* s = source(sourceName, false);
 
@@ -121,6 +128,9 @@ class DataEngine::Private
                     if (s) {
                         // now we have a source; since it was created on demand, assume
                         // it should be removed when not used
+                        if (newSource) {
+                            *newSource = true;
+                        }
                         connect(s, SIGNAL(unused(QString)), engine, SLOT(removeSource(QString)));
                     }
                 }
@@ -185,10 +195,14 @@ void DataEngine::connectSource(const QString& source, QObject* visualization,
                                uint updateInterval, Plasma::IntervalAlignment intervalAlignment) const
 {
     //kDebug() << "connectSource" << source;
-    DataContainer* s = d->requestSource(source);
+    bool newSource;
+    DataContainer* s = d->requestSource(source, &newSource);
 
     if (s) {
-        d->connectSource(s, visualization, updateInterval, intervalAlignment);
+        // we suppress the immediate invocation of dataUpdated here if the source was prexisting and they
+        // don't request delayed updates (we want to do an immediate update in that case so they
+        // don't have to wait for the first time out)
+        d->connectSource(s, visualization, updateInterval, intervalAlignment, !newSource || updateInterval > 0);
         //kDebug() << " ==> source connected";
     }
 }
@@ -212,7 +226,7 @@ void DataEngine::disconnectSource(const QString& source, QObject* visualization)
 
 DataContainer* DataEngine::containerForSource(const QString &source)
 {
-    return d->requestSource(source);
+    return d->source(source, false);
 }
 
 DataEngine::Data DataEngine::query(const QString& source) const
@@ -238,9 +252,11 @@ void DataEngine::internalUpdateSource(DataContainer* source)
     if (d->minUpdateInterval > 0 &&
         source->timeSinceLastUpdate() < d->minUpdateInterval) {
         // skip updating this source; it's been too soon
-        //TODO: should we queue an update in this case? return to this
-        //      once we see the results in real world usage
         //kDebug() << "internal update source is delaying" << source->timeSinceLastUpdate() << d->minUpdateInterval;
+        //but fake an update so that the signalrelay that triggered this gets the data from the
+        //recent update. this way we don't have to worry about queuing - the relay will send a
+        //signal immediately and everyone else is undisturbed.
+        source->setNeedsUpdate();
         return;
     }
 
@@ -411,6 +427,11 @@ bool DataEngine::isValid() const
     return d->valid;
 }
 
+bool DataEngine::isEmpty() const
+{
+    return d->sources.isEmpty();
+}
+
 void DataEngine::setValid(bool valid)
 {
     d->valid = valid;
