@@ -39,7 +39,6 @@ class PLASMA_EXPORT Phase : public QObject
 {
     Q_OBJECT
     Q_ENUMS( Animation )
-    Q_ENUMS( RenderOp )
     Q_ENUMS( CurveShape )
     Q_ENUMS( Movement )
 
@@ -58,11 +57,6 @@ public:
         ElementDisappear /*<< Animate the disappearance of an element */
     };
 
-    enum RenderOp
-    {
-        RenderBackground = 0 /*<< Render the background of an item */
-    };
-
     enum CurveShape
     {
         EaseInCurve = 0,
@@ -89,22 +83,52 @@ public:
 
     Q_INVOKABLE void animateItem(QGraphicsItem* item, Animation anim);
     Q_INVOKABLE void moveItem(QGraphicsItem* item, Movement movement, const QPoint &destination);
-    Q_INVOKABLE void render(QGraphicsItem* item, QImage& image, RenderOp op);
 
-    AnimId animateElement(QGraphicsItem *obj, ElementAnimation);
-    void stopElementAnimation(AnimId id);
-    void setAnimationPixmap(AnimId id, const QPixmap &pixmap);
-    QPixmap animationResult(AnimId id);
+    /**
+     * Starts a custom animation, preventing the need to create a timeline
+     * with its own timer tick.
+     *
+     * @arg frames the number of frames this animation should persist for
+     * @arg duration the length, in milliseconds, the animation will take
+     * @arg curve the curve applied to the frame rate
+     * @arg receive the object that will handle the actual animation
+     * @arg method the method name of slot to be invoked on each update.
+     *             It must take a qreal. So if the slot is animate(qreal),
+     *             pass in "animate" as the method parameter.
+     *
+     * @return an id that can be used to identify this animation.
+     */
+    Q_INVOKABLE AnimId customAnimation(int frames, int duration, Phase::CurveShape curve,
+                                       QObject* receiver, const char* method);
+
+    /**
+     * Stops a custom animation. Note that it is not necessary to call
+     * this on object destruction, as custom animations associated with
+     * a given QObject are cleaned up automatically on QObject destruction.
+     *
+     * @arg id the id of the animation as returned by customAnimation
+     */
+    Q_INVOKABLE void stopCustomAnimation(AnimId id);
+
+    Q_INVOKABLE AnimId animateElement(QGraphicsItem *obj, ElementAnimation);
+    Q_INVOKABLE void stopElementAnimation(AnimId id);
+    Q_INVOKABLE void setAnimationPixmap(AnimId id, const QPixmap &pixmap);
+    Q_INVOKABLE QPixmap animationResult(AnimId id);
 
 Q_SIGNALS:
-    void animationComplete(QGraphicsItem *item, Animation anim);
+    void animationComplete(QGraphicsItem *item, Plasma::Phase::Animation anim);
     void movementComplete(QGraphicsItem *item);
+    void elementAnimationComplete(AnimId id);
+    void customAnimationComplete(AnimId id);
 
 protected:
     void timerEvent(QTimerEvent *event);
 
 protected Q_SLOTS:
-    void appletDestroyed(QObject*);
+    void animatedItemDestroyed(QObject*);
+    void movingItemDestroyed(QObject*);
+    void animatedElementDestroyed(QObject*);
+    void customAnimReceiverDestroyed(QObject*);
 
 private:
     void init();
