@@ -28,7 +28,7 @@
 
 #include <plasma/dataengine.h>
 #include <plasma/plasma.h>
-#include <plasma/widgets/layoutitem.h>
+#include <plasma/layouts/layoutitem.h>
 
 namespace Plasma
 {
@@ -46,12 +46,11 @@ class PLASMA_EXPORT LineEdit : public QGraphicsTextItem, public LayoutItem
     Q_PROPERTY( QString plainText READ toPlainText )
 
     public:
-        explicit LineEdit(QGraphicsItem *parent = 0, QGraphicsScene *scene = 0);
+        explicit LineEdit(QGraphicsItem *parent = 0);
         ~LineEdit();
 
-        void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
         void paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
-       
+
         Qt::Orientations expandingDirections() const;
 
         QSizeF minimumSize() const;
@@ -71,6 +70,7 @@ class PLASMA_EXPORT LineEdit : public QGraphicsTextItem, public LayoutItem
 
         QRectF geometry() const;
         void setGeometry(const QRectF& geometry);
+        void updateGeometry();
         QSizeF sizeHint() const;
 
         void setDefaultText(const QString &text);
@@ -88,7 +88,7 @@ class PLASMA_EXPORT LineEdit : public QGraphicsTextItem, public LayoutItem
         void textChanged(const QString &text);
 
     public Q_SLOTS:
-        void updated(const QString&, const Plasma::DataEngine::Data&);
+        void dataUpdated(const QString&, const Plasma::DataEngine::Data&);
 
     private:
         class Private;
