@@ -123,9 +123,9 @@ void RadioButton::setChecked(bool checked)
             }
         }
     }
-    // If not, we should be on a scene, not flying anywhere
     else if (checked && !parentItem() && scene())
     {
+        // we should be on a scene, not flying anywhere
         foreach(QGraphicsItem *sibling, scene()->items())
         {
             siblingRadioButton = dynamic_cast<RadioButton*>(sibling);
@@ -149,9 +149,17 @@ void RadioButton::setText(const QString &text)
     update();
 }
 
-void RadioButton::updated(const QString&, const Plasma::DataEngine::Data &data)
+void RadioButton::dataUpdated(const QString&, const Plasma::DataEngine::Data &data)
 {
-    Q_UNUSED(data);
+    DataEngine::DataIterator it(data);
+
+    while (it.hasNext()) {
+        it.next();
+        if (it.value().canConvert(QVariant::Bool)) {
+            setChecked(it.value().toBool());
+            return;
+        }
+    }
 }
 
 void RadioButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
@@ -165,10 +173,13 @@ void RadioButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
     event->accept();
     d->mouseDown = false;
-    setChecked(true);
-    update();
 
-    emit clicked();
+    if (sceneBoundingRect().contains(event->scenePos())) {
+        setChecked(true);
+        emit clicked();
+    }
+
+    update();
 }
 
 void RadioButton::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
@@ -190,6 +201,7 @@ void RadioButton::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
     event->accept();
     d->mouseOver = false;
     update();
+    Widget::hoverLeaveEvent(event);
 }
 
 void RadioButton::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
@@ -197,6 +209,7 @@ void RadioButton::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
     event->accept();
     d->mouseOver = true;
     update();
+    Widget::hoverEnterEvent(event);
 }
 
 
