@@ -255,7 +255,7 @@ void SignalPlotter::scale(qreal delta)
     calculateNiceRange();
 }
 
-double SignalPlotter::scaledBy() const
+qreal SignalPlotter::scaledBy() const
 {
     return d->scaledBy;
 }
@@ -516,6 +516,13 @@ QPixmap SignalPlotter::getSnapshotImage(uint w, uint height)
     return image;
 }
 
+void SignalPlotter::setGeometry(const QRectF &geometry)
+{
+    // First update our size, then update the data buffers accordingly.
+    Widget::setGeometry(geometry);
+    updateDataBuffers();
+}
+
 void SignalPlotter::paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     Q_UNUSED(option);
@@ -653,7 +660,7 @@ void SignalPlotter::calculateNiceRange()
     // Massage the range so that the grid shows some nice values.
     double step = d->niceVertRange / (d->scaledBy*(d->horizontalLinesCount+1));
     int logdim = (int)floor(log10(step));
-    double dim = pow(10, logdim) / 2;
+    double dim = pow((double)10.0, logdim) / 2;
     int a = (int)ceil(step / dim);
     if (logdim >= 0)
         d->precision = 0;
