@@ -23,18 +23,33 @@
 #define WIDGET_H_
 
 #include <QtGui/QGraphicsItem>
+#include <QtGui/QPixmap>
 
 #include <QtCore/QRectF>
 #include <QtCore/QSizeF>
+#include <QtCore/QString>
 
-#include <plasma/widgets/layoutitem.h>
+#include <plasma/layouts/layoutitem.h>
 #include <plasma/plasma_export.h>
 
+class QGraphicsView;
+class QGraphicsSceneHoverEvent;
+
 namespace Plasma
 {
 
+struct PLASMA_EXPORT ToolTipData
+{
+    ToolTipData() : windowToPreview( 0 ) {}
+    QString mainText; //Important information
+    QString subText; //Elaborates on the Main Text
+    QPixmap image; // Icon to show;
+    WId windowToPreview; // Id of window to show preview
+};
+
 class Layout;
 
+
 /**
  * Base class for all Widgets in Plasma.
  *
@@ -45,7 +60,8 @@ class Layout;
  * Widgets are rectangular, but can be in any visible shape by just using transparency to mask
  * out non-rectangular areas.
  *
- * To implement a Widget, just subclass Plasma::Widget and implement at minimum, sizeHint() and paint()
+ * To implement a Widget, just subclass Plasma::Widget and implement at minimum,
+ * sizeHint() and paintWidget()
  */
 class PLASMA_EXPORT Widget  : public QObject,
                               public QGraphicsItem,
@@ -210,12 +226,6 @@ TODO: implement once we decide how to handle the font system
      */
     Q_INVOKABLE Widget *parent() const;
 
-    /**
-     * Sets the parent of this Plasma::Widget;
-     * @param widget the widget to reparent to.
-     */
-    Q_INVOKABLE void reparent(Widget *widget);
-
     /**
      * Add another Plasma::Widget as a child of this one.
      * @param widget the widget to reparent to this Plasma::Widget.
@@ -247,6 +257,37 @@ TODO: implement once we decide how to handle the font system
 
     virtual QGraphicsItem* graphicsItem();
 
+    /**
+     * Returns the view this widget is visible on
+     */
+    QGraphicsView *view() const;
+
+    /**
+     * Maps a QRect from a view's coordinates to local coordinates.
+     * @param view the view from which rect should be mapped
+     * @param rect the rect to be mapped
+     */
+    QRectF mapFromView(const QGraphicsView *view, const QRect &rect) const;
+
+    /**
+     * Maps a QRectF from local coordinates to a view's coordinates.
+     * @param view the view to which rect should be mapped
+     * @param rect the rect to be mapped
+     */
+    QRect mapToView(const QGraphicsView *view, const QRectF &rect) const;
+
+    /**
+    * The Data from the tooltip
+    * @returns A ToolTip::Data object with current information
+    */
+    ToolTipData toolTip() const;
+
+    /**
+    * Setter for data shown in tooltip
+    * @param data a ToolTip::Data object containing icon and text
+    */
+    void setToolTip( const ToolTipData &dt );
+
 protected:
     /**
      * Paints the widget
@@ -255,7 +296,18 @@ protected:
      * @param widget the parent QWidget (most likely the Corona)
      */
     virtual void paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+
+    /**
+     * Reimplemented from QGraphicsItem
+     */
+    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
+
+    QVariant itemChange(GraphicsItemChange change, const QVariant &value);
+    void setSize(qreal width, qreal height);
     void setSize(const QSizeF& size);
+    void managingLayoutChanged();
+
+    virtual bool sceneEvent(QEvent *event);
 
 private:
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
