@@ -50,7 +50,6 @@ class Clock : public Plasma::Applet
         void init();
         void paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option, const QRect &contentsRect);
         void setPath(const QString&);
-        void constraintsUpdated(Plasma::Constraints);
         void mousePressEvent(QGraphicsSceneMouseEvent *event);
 
         // reimplemented
@@ -82,7 +81,6 @@ class Clock : public Plasma::Applet
         bool m_showYear;
         bool m_showDay;
         bool m_showTimezone;
-        bool m_twentyFour;
 
         QString m_timezone;
         QString m_prettyTimezone;
