@@ -26,7 +26,6 @@
 #include <QScrollBar>
 #include <QStack>
 #include <QTimeLine>
-#include <QtDebug>
 
 // KDE
 #include <KDebug>
@@ -69,6 +68,7 @@ public:
     {
         if (previousRootIndices.isEmpty() || previousRootIndices.top() != index) {
             // we're entering into a submenu
+            //kDebug() << "pushing" << currentRootIndex.data(Qt::DisplayRole).value<QString>();
             animLeftToRight = true;
             hoveredIndex = QModelIndex();
             previousRootIndices.push(currentRootIndex);
@@ -78,9 +78,13 @@ public:
             q->verticalScrollBar()->setValue(0);
         } else {
             // we're exiting to the parent menu
+            //kDebug() << "popping" << previousRootIndices.top().data(Qt::DisplayRole).value<QString>();
             animLeftToRight = false;
             hoveredIndex = currentRootIndex;
             previousRootIndices.pop();
+            //if (!previousRootIndices.isEmpty()) {
+            //    kDebug() << "now the previos root is" << previousRootIndices.top().data(Qt::DisplayRole).value<QString>();
+            //}
             currentRootIndex = index;
             updateScrollBarRange();
             q->verticalScrollBar()->setValue(previousVerticalOffsets.pop());
@@ -217,7 +221,7 @@ public:
     QTimeLine *flipAnimTimeLine;
     bool animLeftToRight;
 
-    static const int FLIP_ANIM_DURATION = 300;
+    static const int FLIP_ANIM_DURATION = 200;
 
 private:
      QPersistentModelIndex currentRootIndex;
@@ -242,6 +246,17 @@ FlipScrollView::~FlipScrollView()
 {
     delete d;
 }
+void FlipScrollView::viewRoot()
+{
+    QModelIndex index;
+    while(d->currentRoot().isValid()) {
+        index = d->currentRoot();
+        d->setCurrentRoot(d->currentRoot().parent());
+        setCurrentIndex(index);
+    }
+    update(d->hoveredIndex);
+    d->hoveredIndex = index;
+}
 QModelIndex FlipScrollView::indexAt(const QPoint& point) const
 {
     int topOffset = d->headerRect(d->currentRoot()).height() - verticalOffset();
@@ -282,7 +297,7 @@ QRect FlipScrollView::visualRect(const QModelIndex& index) const
     int topOffset = d->headerRect(index.parent()).height();
     int leftOffset = d->backArrowRect().width() + ItemDelegate::BACK_ARROW_SPACING;
 
-    if (index.parent() != d->currentRoot() && index.parent() != d->previousRoot()) {
+    if (index.parent() != d->currentRoot() && index.parent() != d->previousRoot() && index.parent() != (QModelIndex)d->hoveredIndex) {
         return QRect();
     }
 
@@ -344,7 +359,7 @@ QRegion FlipScrollView::visualRegionForSelection(const QItemSelection& selection
 QModelIndex FlipScrollView::moveCursor(CursorAction cursorAction,Qt::KeyboardModifiers)
 {
     QModelIndex index = currentIndex();
-   // qDebug() << "Moving cursor with current index" << index.data(Qt::DisplayRole);
+   // kDebug() << "Moving cursor with current index" << index.data(Qt::DisplayRole);
     switch (cursorAction) {
         case MoveUp:
                 if (currentIndex().row() > 0) {
@@ -382,7 +397,7 @@ QModelIndex FlipScrollView::moveCursor(CursorAction cursorAction,Qt::KeyboardMod
     update(d->hoveredIndex);
     d->hoveredIndex = index;
 
-     //qDebug() << "New index after move" << index.data(Qt::DisplayRole);
+     //kDebug() << "New index after move" << index.data(Qt::DisplayRole);
 
     return index;
 }
@@ -475,25 +490,14 @@ void FlipScrollView::keyPressEvent(QKeyEvent *event)
     QAbstractItemView::keyPressEvent(event);
 }
 
-void FlipScrollView::paintEvent(QPaintEvent * event)
+void FlipScrollView::paintItems(QPainter &painter, QPaintEvent *event, QModelIndex &root)
 {
-    QPainter painter(viewport());
-    painter.setRenderHint(QPainter::Antialiasing);
+    const int rows = model()->rowCount(root);
+    //kDebug() << "painting" << rows << "items";
 
-    // draw items
-    QModelIndexList redrawIndexes;
+    for (int i = 0; i < rows; ++i) {
+        QModelIndex index = model()->index(i, 0, root);
 
-    int currentRootRows = model()->rowCount(d->currentRoot());
-    int previousRootRows = model()->rowCount(d->previousRoot());
-
-    for (int i=0;i<currentRootRows;i++) {
-        redrawIndexes << model()->index(i,0,d->currentRoot());
-    }
-    for (int i=0;i<previousRootRows && d->flipAnimTimeLine->currentValue() < 1.0;i++) {
-        redrawIndexes << model()->index(i,0,d->previousRoot());
-    }
-
-    foreach(const QModelIndex& index, redrawIndexes) {
         QStyleOptionViewItem option = viewOptions();
         option.rect = visualRect(index);
 
@@ -540,11 +544,29 @@ void FlipScrollView::paintEvent(QPaintEvent * event)
             painter.restore();
         }
     }
+}
+
+void FlipScrollView::paintEvent(QPaintEvent * event)
+{
+    QPainter painter(viewport());
+    painter.setRenderHint(QPainter::Antialiasing);
+
+    // draw items
+    QModelIndex currentRoot = d->currentRoot();
+    QModelIndex previousRoot = d->animLeftToRight ? d->previousRoot() : (QModelIndex)d->hoveredIndex;
+    //kDebug() << "current root is" << currentRoot.data(Qt::DisplayRole).value<QString>();
+
+    paintItems(painter, event, currentRoot);
 
     const qreal timerValue = d->flipAnimTimeLine->currentValue();
 
+    if (timerValue < 1.0) {
+        //kDebug() << "previous root is" << previousRoot.data(Qt::DisplayRole).value<QString>();
+        paintItems(painter, event, previousRoot);
+    }
+
     // draw header for current view
-    QRect headerRect = d->headerRect(d->currentRoot());
+    QRect headerRect = d->headerRect(currentRoot);
     if (d->animLeftToRight) {
         headerRect.translate((int)(headerRect.width()*(1-timerValue)),0);
     } else {
@@ -552,11 +574,11 @@ void FlipScrollView::paintEvent(QPaintEvent * event)
     }
 
     if (event->rect().intersects(headerRect)) {
-        d->drawHeader(&painter,headerRect,d->currentRoot());
+        d->drawHeader(&painter,headerRect,currentRoot);
     }
 
     // draw header for previous view
-    QRect prevHeaderRect = d->headerRect(d->previousRoot());
+    QRect prevHeaderRect = d->headerRect(previousRoot);
     if (d->animLeftToRight) {
         prevHeaderRect.translate((int)(-prevHeaderRect.width()*timerValue),0);
     } else {
@@ -564,12 +586,12 @@ void FlipScrollView::paintEvent(QPaintEvent * event)
     }
 
     if (event->rect().intersects(prevHeaderRect) && timerValue < 1.0) {
-        d->drawHeader(&painter,prevHeaderRect,d->previousRoot());
+        d->drawHeader(&painter,prevHeaderRect,previousRoot);
     }
 
     // draw navigation
     QStyle::State state = 0;
-    if (d->currentRoot().isValid()) {
+    if (currentRoot.isValid()) {
         state |= QStyle::State_Enabled;
     }
 
@@ -577,11 +599,11 @@ void FlipScrollView::paintEvent(QPaintEvent * event)
         state |= QStyle::State_MouseOver;
     }
 
-    if (d->currentRoot().isValid() || d->previousRoot().isValid()) {
+    if (currentRoot.isValid() || previousRoot.isValid()) {
         qreal opacity = 1.0;
-        if (!d->previousRoot().isValid()) {
+        if (!previousRoot.isValid()) {
             opacity = timerValue;   
-        } else if (!d->currentRoot().isValid()) {
+        } else if (!currentRoot.isValid()) {
             opacity = 1-timerValue;
         }
 
