@@ -67,14 +67,14 @@ class Pager : public Plasma::Applet
 	void activeWindowChanged(WId id);
 	void numberOfDesktopsChanged(int num);
 	void stackingOrderChanged();
-	void windowChanged(WId id);
+	void windowChanged(WId id, unsigned int properties);
   	void showingDesktopChanged(bool showing);
         void slotConfigureDesktop();
         void lostDesktopLayoutOwner();
 
     protected:
         void createMenu();
-
+        QRect fixViewportPosition( const QRect& r );
     private:
 	QTimer* m_timer;
         KDialog *m_dialog;
