@@ -30,6 +30,11 @@
 // Plasma
 #include <plasma/applet.h>
 
+namespace Plasma
+{
+    class LayoutAnimator;
+} // namespace Plasma
+
 class AbstractTaskItem;
 class TaskGroupItem;
 
@@ -86,6 +91,9 @@ private slots:
         void addStartingTask(StartupPtr);
         void removeStartingTask(StartupPtr);
 
+        void currentDesktopChanged(int);
+        void taskMovedDesktop(TaskPtr task);
+
 private:
         // creates task representations for existing windows
         // and sets up connections to listen for addition or removal
@@ -102,14 +110,19 @@ private:
         void addItemToRootGroup(AbstractTaskItem* item);
         void removeItemFromRootGroup(AbstractTaskItem* item);
 
-        TaskGroupItem* _rootTaskGroup;
+        // remove all tasks from the taskbar
+        void removeAllWindowTasks();
 
-        QHash<TaskPtr,AbstractTaskItem*> _windowTaskItems;
-        QHash<StartupPtr,AbstractTaskItem*> _startupTaskItems;
+        TaskGroupItem* m_rootTaskGroup;
 
-        bool _showTooltip;
+        QHash<TaskPtr,AbstractTaskItem*> m_windowTaskItems;
+        QHash<StartupPtr,AbstractTaskItem*> m_startupTaskItems;
+
+        bool m_showTooltip;
+        bool m_showOnlyCurrentDesktop;
+        Plasma::LayoutAnimator *m_animator;
         KDialog *m_dialog;
-        Ui::tasksConfig ui;
+        Ui::tasksConfig m_ui;
 };
 
 K_EXPORT_PLASMA_APPLET(tasks, Tasks)
