@@ -27,6 +27,7 @@
 #include <kdebug.h>
 #include <kservicetypetrader.h>
 #include <QApplication>
+#include <kdialog.h>
 
 #include "kcmsearch.h"
 #include "moduleiconitem.h"
@@ -36,16 +37,17 @@ ModulesView::ModulesView( KCModuleMenu *rootMenu, const QString &menuPath, QWidg
 {
 	this->rootMenu = rootMenu;	
 	this->menuPath = menuPath;
+	this->categories = KServiceTypeTrader::self()->query("SystemSettingsCategory");
 
 	QVBoxLayout *layout = new QVBoxLayout( this );
-	layout->setMargin( 11 );
-	layout->setSpacing( 6 );
+	layout->setMargin( KDialog::marginHint() );
+	layout->setSpacing( KDialog::spacingHint() );
 	layout->setObjectName( QLatin1String( "layout" ) );
 
 	displayName = this->rootMenu->caption;
 
 	QList<MenuItem> subMenus = rootMenu->menuList(menuPath);
- 	QList<MenuItem>::const_iterator it;
+	QList<MenuItem>::const_iterator it;
 	for ( it = subMenus.begin(); it != subMenus.end(); ++it ){
 		if( !(*it).menu )
 			continue;
@@ -67,18 +69,17 @@ ModulesView::ModulesView( KCModuleMenu *rootMenu, const QString &menuPath, QWidg
 	setBackgroundRole(QPalette::Base);
 	setForegroundRole(QPalette::Text);
 
+	/*
 	// Align them up!
-/*FIXME
-	{
 	uint most = 0;
-	QList<RowIconView*>::iterator it;
-	for ( it = groups.begin(); it != groups.end(); ++it ){
-		Q3IconViewItem *item = (*it)->firstItem();
-		while( item ) {
-			if(item->width() > most)
-				most = item->width();
-			item = item->nextItem();
-		}
+	QList<RowIconView*>::iterator it2;
+	for ( it2 = groups.begin(); it2 != groups.end(); ++it2 ){
+		for (int i = 0; i < (*it2)->count(); ++i ) {
+			QListWidgetItem * item = (*it2)->item( i );
+			if ( item && item->sizeHint().width() > most ) {
+				most = item->sizeHint().width();
+			}
+			}
 	}
 */
 /*FIXME
@@ -97,7 +98,6 @@ void ModulesView::createRow( const QString &parentPath, QBoxLayout *boxLayout )
 {
 	//find the category name and search for it
 	QString categoryName = parentPath.section('/', -2, -2);
-	KService::List categories = KServiceTypeTrader::self()->query("SystemSettingsCategory");
 	QString iconName;
 	for (int i = 0; i < categories.size(); ++i) {
 		const KService* entry = categories.at(i).data();
@@ -148,7 +148,7 @@ void ModulesView::createRow( const QString &parentPath, QBoxLayout *boxLayout )
 	int height = 0;
 	// Add all the items in their proper order
 	QList<MenuItem> list = rootMenu->menuList( parentPath );
- 	QList<MenuItem>::const_iterator it;
+	QList<MenuItem>::const_iterator it;
 	for ( it = list.begin(); it != list.end(); ++it ){
 		ModuleIconItem *item = NULL;
 		if( !(*it).menu ) {
@@ -156,7 +156,7 @@ void ModulesView::createRow( const QString &parentPath, QBoxLayout *boxLayout )
 		} else {
 			QString path = (*it).subMenu;
 
-			QString categoryCaption = path.section('/', -2, -2);
+			QString categoryCaption = (*it).caption;
 			QString iconFile;
 			for (int i = 0; i < categories.size(); ++i) {
 				const KService* entry = categories.at(i).data();
@@ -167,7 +167,7 @@ void ModulesView::createRow( const QString &parentPath, QBoxLayout *boxLayout )
 			}
 
 			const QList<KCModuleInfo> &modules = rootMenu->modules( path );
-			if ( ! iconFile.isEmpty() && modules.count() > 0 ) {
+			if ( modules.count() > 0 ) {
 				item = new ModuleIconItem( iconWidget, categoryCaption, iconFile);
 				item->modules = modules;
 			}
